/* collection-view.c generated by valac 0.29.2.1-265d, the Vala compiler
 * generated from collection-view.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <libgd/gd.h>
#include <gtk/gtk.h>
#include <gdk/gdk.h>
#include <gio/gio.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <libcommon.h>
#include <stdlib.h>
#include <string.h>
#include <glib/gi18n-lib.h>


#define BOXES_TYPE_SELECTION_CRITERIA (boxes_selection_criteria_get_type ())

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_UI_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_UI, BoxesUIIface))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIIface BoxesUIIface;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())

#define BOXES_TYPE_COLLECTION_VIEW (boxes_collection_view_get_type ())
#define BOXES_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView))
#define BOXES_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))
#define BOXES_IS_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_IS_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_COLLECTION_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))

typedef struct _BoxesCollectionView BoxesCollectionView;
typedef struct _BoxesCollectionViewClass BoxesCollectionViewClass;
typedef struct _BoxesCollectionViewPrivate BoxesCollectionViewPrivate;

#define BOXES_TYPE_APP_WINDOW (boxes_app_window_get_type ())
#define BOXES_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindow))
#define BOXES_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))
#define BOXES_IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP_WINDOW))
#define BOXES_IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP_WINDOW))
#define BOXES_APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))

typedef struct _BoxesAppWindow BoxesAppWindow;
typedef struct _BoxesAppWindowClass BoxesAppWindowClass;

#define BOXES_TYPE_CATEGORY (boxes_category_get_type ())
#define BOXES_CATEGORY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_CATEGORY, BoxesCategory))
#define BOXES_CATEGORY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_CATEGORY, BoxesCategoryClass))
#define BOXES_IS_CATEGORY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_CATEGORY))
#define BOXES_IS_CATEGORY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_CATEGORY))
#define BOXES_CATEGORY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_CATEGORY, BoxesCategoryClass))

typedef struct _BoxesCategory BoxesCategory;
typedef struct _BoxesCategoryClass BoxesCategoryClass;

#define BOXES_TYPE_ACTIONS_POPOVER (boxes_actions_popover_get_type ())
#define BOXES_ACTIONS_POPOVER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_ACTIONS_POPOVER, BoxesActionsPopover))
#define BOXES_ACTIONS_POPOVER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_ACTIONS_POPOVER, BoxesActionsPopoverClass))
#define BOXES_IS_ACTIONS_POPOVER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_ACTIONS_POPOVER))
#define BOXES_IS_ACTIONS_POPOVER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_ACTIONS_POPOVER))
#define BOXES_ACTIONS_POPOVER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_ACTIONS_POPOVER, BoxesActionsPopoverClass))

typedef struct _BoxesActionsPopover BoxesActionsPopover;
typedef struct _BoxesActionsPopoverClass BoxesActionsPopoverClass;

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_COLLECTION_VIEW_TYPE_MODEL_COLUMNS (boxes_collection_view_model_columns_get_type ())
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))
typedef struct _Block18Data Block18Data;

#define BOXES_TYPE_MACHINE (boxes_machine_get_type ())
#define BOXES_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE, BoxesMachine))
#define BOXES_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE, BoxesMachineClass))
#define BOXES_IS_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE))
#define BOXES_IS_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE))
#define BOXES_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE, BoxesMachineClass))

typedef struct _BoxesMachine BoxesMachine;
typedef struct _BoxesMachineClass BoxesMachineClass;
typedef struct _BoxesCollectionItemPrivate BoxesCollectionItemPrivate;

#define BOXES_TYPE_IPROPERTIES_PROVIDER (boxes_iproperties_provider_get_type ())
#define BOXES_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProvider))
#define BOXES_IS_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER))
#define BOXES_IPROPERTIES_PROVIDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProviderIface))

typedef struct _BoxesIPropertiesProvider BoxesIPropertiesProvider;
typedef struct _BoxesIPropertiesProviderIface BoxesIPropertiesProviderIface;

#define BOXES_TYPE_PROPERTIES_PAGE (boxes_properties_page_get_type ())

#define TYPE_PROPERTY_CREATION_FLAG (property_creation_flag_get_type ())

#define BOXES_TYPE_PROPERTY (boxes_property_get_type ())
#define BOXES_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTY, BoxesProperty))
#define BOXES_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTY, BoxesPropertyClass))
#define BOXES_IS_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTY))
#define BOXES_IS_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTY))
#define BOXES_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTY, BoxesPropertyClass))

typedef struct _BoxesProperty BoxesProperty;
typedef struct _BoxesPropertyClass BoxesPropertyClass;
typedef struct _BoxesMachinePrivate BoxesMachinePrivate;

#define BOXES_MACHINE_TYPE_CONNECT_FLAGS (boxes_machine_connect_flags_get_type ())
#define _gtk_icon_info_free0(var) ((var == NULL) ? NULL : (var = (gtk_icon_info_free (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _Block19Data Block19Data;
typedef struct _Block20Data Block20Data;
typedef struct _Block21Data Block21Data;

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;
typedef struct _BoxesAppPrivate BoxesAppPrivate;

#define BOXES_TYPE_COLLECTION (boxes_collection_get_type ())
#define BOXES_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION, BoxesCollection))
#define BOXES_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION, BoxesCollectionClass))
#define BOXES_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION))
#define BOXES_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION))
#define BOXES_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION, BoxesCollectionClass))

typedef struct _BoxesCollection BoxesCollection;
typedef struct _BoxesCollectionClass BoxesCollectionClass;

#define BOXES_TYPE_COLLECTION_FILTER (boxes_collection_filter_get_type ())
#define BOXES_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilter))
#define BOXES_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))
#define BOXES_IS_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_IS_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_COLLECTION_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))

typedef struct _BoxesCollectionFilter BoxesCollectionFilter;
typedef struct _BoxesCollectionFilterClass BoxesCollectionFilterClass;
#define _gtk_tree_path_free0(var) ((var == NULL) ? NULL : (var = (gtk_tree_path_free (var), NULL)))

#define BOXES_TYPE_LIBVIRT_MACHINE (boxes_libvirt_machine_get_type ())
#define BOXES_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachine))
#define BOXES_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))
#define BOXES_IS_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_IS_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_LIBVIRT_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))

typedef struct _BoxesLibvirtMachine BoxesLibvirtMachine;
typedef struct _BoxesLibvirtMachineClass BoxesLibvirtMachineClass;
typedef struct _Block22Data Block22Data;
typedef struct _Block23Data Block23Data;

#define BOXES_MACHINE_TYPE_MACHINE_STATE (boxes_machine_machine_state_get_type ())

#define BOXES_CATEGORY_TYPE_KIND (boxes_category_kind_get_type ())

typedef enum  {
	BOXES_SELECTION_CRITERIA_ALL,
	BOXES_SELECTION_CRITERIA_NONE,
	BOXES_SELECTION_CRITERIA_RUNNING
} BoxesSelectionCriteria;

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUIIface {
	GTypeInterface parent_iface;
	BoxesUIState (*get_previous_ui_state) (BoxesUI* self);
	void (*set_previous_ui_state) (BoxesUI* self, BoxesUIState value);
	BoxesUIState (*get_ui_state) (BoxesUI* self);
	void (*set_ui_state) (BoxesUI* self, BoxesUIState value);
};

struct _BoxesCollectionView {
	GdMainView parent_instance;
	BoxesCollectionViewPrivate * priv;
};

struct _BoxesCollectionViewClass {
	GdMainViewClass parent_class;
};

struct _BoxesCollectionViewPrivate {
	BoxesUIState _previous_ui_state;
	BoxesUIState _ui_state;
	BoxesAppWindow* window;
	BoxesCategory* _category;
	GtkListStore* store;
	GtkTreeModelFilter* model_filter;
	BoxesActionsPopover* context_popover;
	GList* hidden_items;
};

typedef enum  {
	BOXES_COLLECTION_VIEW_MODEL_COLUMNS_SCREENSHOT = GD_MAIN_COLUMN_ICON,
	BOXES_COLLECTION_VIEW_MODEL_COLUMNS_TITLE = GD_MAIN_COLUMN_PRIMARY_TEXT,
	BOXES_COLLECTION_VIEW_MODEL_COLUMNS_INFO = GD_MAIN_COLUMN_SECONDARY_TEXT,
	BOXES_COLLECTION_VIEW_MODEL_COLUMNS_SELECTED = GD_MAIN_COLUMN_SELECTED,
	BOXES_COLLECTION_VIEW_MODEL_COLUMNS_PULSE = GD_MAIN_COLUMN_PULSE,
	BOXES_COLLECTION_VIEW_MODEL_COLUMNS_ITEM = GD_MAIN_COLUMN_LAST,
	BOXES_COLLECTION_VIEW_MODEL_COLUMNS_LAST
} BoxesCollectionViewModelColumns;

struct _Block18Data {
	int _ref_count_;
	BoxesCollectionView* self;
	BoxesAppWindow* window;
};

struct _BoxesCollectionItem {
	GObject parent_instance;
	BoxesCollectionItemPrivate * priv;
};

struct _BoxesCollectionItemClass {
	GObjectClass parent_class;
	gint (*compare) (BoxesCollectionItem* self, BoxesCollectionItem* other);
};

typedef enum  {
	BOXES_PROPERTIES_PAGE_GENERAL,
	BOXES_PROPERTIES_PAGE_SYSTEM,
	BOXES_PROPERTIES_PAGE_DEVICES,
	BOXES_PROPERTIES_PAGE_SNAPSHOTS,
	BOXES_PROPERTIES_PAGE_LAST
} BoxesPropertiesPage;

typedef enum  {
	PROPERTY_CREATION_FLAG_NONE = 1 << 0,
	PROPERTY_CREATION_FLAG_NO_USB = 1 << 1
} PropertyCreationFlag;

struct _BoxesIPropertiesProviderIface {
	GTypeInterface parent_iface;
	GList* (*get_properties) (BoxesIPropertiesProvider* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
};

typedef enum  {
	BOXES_MACHINE_CONNECT_FLAGS_NONE = 0,
	BOXES_MACHINE_CONNECT_FLAGS_IGNORE_SAVED_STATE = 1 << 0
} BoxesMachineConnectFlags;

struct _BoxesMachine {
	BoxesCollectionItem parent_instance;
	BoxesMachinePrivate * priv;
	BoxesCollectionSource* source;
	BoxesBoxConfig* config;
	gboolean stay_on_display;
	gboolean suspend_at_exit;
};

struct _BoxesMachineClass {
	BoxesCollectionItemClass parent_class;
	void (*save_real) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*save_real_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*take_screenshot) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GdkPixbuf* (*take_screenshot_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	GList* (*get_properties) (BoxesMachine* self, BoxesPropertiesPage page, PropertyCreationFlag* flags);
	void (*connect_display) (BoxesMachine* self, BoxesMachineConnectFlags flags, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*connect_display_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*restart) (BoxesMachine* self);
	void (*disconnect_display) (BoxesMachine* self);
	void (*delete) (BoxesMachine* self, gboolean by_user);
	gboolean (*get_can_save) (BoxesMachine* self);
	gboolean (*get_should_autosave) (BoxesMachine* self);
};

struct _Block19Data {
	int _ref_count_;
	BoxesCollectionView* self;
	BoxesMachine* machine;
	BoxesAppWindow* window;
	GtkTreeIter iter;
	BoxesCollectionItem* item;
};

struct _Block20Data {
	int _ref_count_;
	Block19Data * _data19_;
	gulong ui_state_id;
};

struct _Block21Data {
	int _ref_count_;
	BoxesCollectionView* self;
	GList* selected;
};

struct _BoxesApp {
	GtkApplication parent_instance;
	BoxesAppPrivate * priv;
	BoxesCollection* collection;
	BoxesCollectionFilter* filter;
};

struct _BoxesAppClass {
	GtkApplicationClass parent_class;
};

struct _Block22Data {
	int _ref_count_;
	BoxesCollectionView* self;
	BoxesSelectionCriteria selection;
};

struct _Block23Data {
	int _ref_count_;
	BoxesCollectionView* self;
	gint pulse;
	BoxesMachine* machine;
};

typedef enum  {
	BOXES_MACHINE_MACHINE_STATE_UNKNOWN,
	BOXES_MACHINE_MACHINE_STATE_STOPPED,
	BOXES_MACHINE_MACHINE_STATE_FORCE_STOPPED,
	BOXES_MACHINE_MACHINE_STATE_RUNNING,
	BOXES_MACHINE_MACHINE_STATE_PAUSED,
	BOXES_MACHINE_MACHINE_STATE_SAVED,
	BOXES_MACHINE_MACHINE_STATE_SLEEPING
} BoxesMachineMachineState;

typedef enum  {
	BOXES_CATEGORY_KIND_USER,
	BOXES_CATEGORY_KIND_NEW,
	BOXES_CATEGORY_KIND_FAVORITES,
	BOXES_CATEGORY_KIND_PRIVATE,
	BOXES_CATEGORY_KIND_SHARED
} BoxesCategoryKind;


static gpointer boxes_collection_view_parent_class = NULL;
extern BoxesApp* boxes_app_app;
static BoxesUIIface* boxes_collection_view_boxes_ui_parent_iface = NULL;

GType boxes_selection_criteria_get_type (void) G_GNUC_CONST;
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_collection_view_get_type (void) G_GNUC_CONST;
GType boxes_app_window_get_type (void) G_GNUC_CONST;
GType boxes_category_get_type (void) G_GNUC_CONST;
GType boxes_actions_popover_get_type (void) G_GNUC_CONST;
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
#define BOXES_COLLECTION_VIEW_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewPrivate))
enum  {
	BOXES_COLLECTION_VIEW_DUMMY_PROPERTY,
	BOXES_COLLECTION_VIEW_PREVIOUS_UI_STATE,
	BOXES_COLLECTION_VIEW_UI_STATE,
	BOXES_COLLECTION_VIEW_CATEGORY
};
static GType boxes_collection_view_model_columns_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static void _g_object_unref0_ (gpointer var);
static void _g_list_free__g_object_unref0_ (GList* self);
void boxes_collection_view_setup_ui (BoxesCollectionView* self, BoxesAppWindow* window);
static Block18Data* block18_data_ref (Block18Data* _data18_);
static void block18_data_unref (void * _userdata_);
static void __lambda14_ (Block18Data* _data18_);
gboolean boxes_app_window_get_selection_mode (BoxesAppWindow* self);
static void ___lambda14__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static gboolean boxes_collection_view_on_button_press_event (BoxesCollectionView* self, GdkEventButton* event);
static gboolean _boxes_collection_view_on_button_press_event_gtk_widget_button_release_event (GtkWidget* _sender, GdkEventButton* event, gpointer self);
static gboolean boxes_collection_view_on_key_press_event (BoxesCollectionView* self, GdkEventKey* event);
static gboolean _boxes_collection_view_on_key_press_event_gtk_widget_key_press_event (GtkWidget* _sender, GdkEventKey* event, gpointer self);
BoxesActionsPopover* boxes_actions_popover_new (BoxesAppWindow* window);
BoxesActionsPopover* boxes_actions_popover_construct (GType object_type, BoxesAppWindow* window);
static void boxes_collection_view_ui_state_changed (BoxesCollectionView* self);
BoxesUIState boxes_ui_get_ui_state (BoxesUI* self);
static void boxes_collection_view_update_screenshot (BoxesCollectionView* self, GtkTreeIter* iter);
GType boxes_machine_get_type (void) G_GNUC_CONST;
GdkPixbuf* boxes_machine_get_pixbuf (BoxesMachine* self);
GType boxes_properties_page_get_type (void) G_GNUC_CONST;
GType property_creation_flag_get_type (void) G_GNUC_CONST;
GType boxes_property_get_type (void) G_GNUC_CONST;
GType boxes_iproperties_provider_get_type (void) G_GNUC_CONST;
GType boxes_machine_connect_flags_get_type (void) G_GNUC_CONST;
static gboolean _vala_string_array_contains (gchar** stack, int stack_length, gchar* needle);
GIcon* boxes_create_symbolic_emblem (const gchar* name);
static void _vala_array_add3 (GIcon*** array, int* length, int* size, GIcon* value);
static void boxes_collection_view_append (BoxesCollectionView* self, const gchar* title, const gchar* info, BoxesCollectionItem* item, GtkTreeIter* result);
static GtkTreeIter* _gtk_tree_iter_dup (GtkTreeIter* self);
void boxes_collection_view_add_item (BoxesCollectionView* self, BoxesCollectionItem* item);
static Block19Data* block19_data_ref (Block19Data* _data19_);
static void block19_data_unref (void * _userdata_);
BoxesAppWindow* boxes_machine_get_window (BoxesMachine* self);
static Block20Data* block20_data_ref (Block20Data* _data20_);
static void block20_data_unref (void * _userdata_);
static void ___lambda17_ (Block20Data* _data20_);
static void ____lambda17__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
const gchar* boxes_collection_item_get_name (BoxesCollectionItem* self);
const gchar* boxes_machine_get_info (BoxesMachine* self);
static void __lambda18_ (Block19Data* _data19_);
static void ___lambda18__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void __lambda19_ (Block19Data* _data19_);
static void ___lambda19__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void __lambda20_ (Block19Data* _data19_);
static void ___lambda20__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void __lambda21_ (Block19Data* _data19_);
static void ___lambda21__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void boxes_collection_view_setup_activity (BoxesCollectionView* self, GtkTreeIter* iter, BoxesMachine* machine);
static void __lambda23_ (Block19Data* _data19_);
static void ___lambda23__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void __lambda24_ (Block19Data* _data19_);
static void ___lambda24__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
void boxes_ui_set_state (BoxesUI* self, BoxesUIState new_state);
GList* boxes_collection_view_get_selected_items (BoxesCollectionView* self);
static Block21Data* block21_data_ref (Block21Data* _data21_);
static void block21_data_unref (void * _userdata_);
static gboolean __lambda25_ (Block21Data* _data21_, GtkTreeModel* store, GtkTreePath* path, GtkTreeIter* iter);
static gboolean ___lambda25__gtk_tree_model_foreach_func (GtkTreeModel* model, GtkTreePath* path, GtkTreeIter* iter, gpointer self);
void boxes_collection_view_remove_item (BoxesCollectionView* self, BoxesCollectionItem* item);
static BoxesCollectionItem* boxes_collection_view_get_item_for_iter (BoxesCollectionView* self, GtkTreeIter* iter);
static BoxesCollectionItem* boxes_collection_view_get_item_for_path (BoxesCollectionView* self, GtkTreePath* path);
static gboolean boxes_collection_view_model_visible (BoxesCollectionView* self, GtkTreeModel* model, GtkTreeIter* iter);
GType boxes_app_get_type (void) G_GNUC_CONST;
GType boxes_collection_get_type (void) G_GNUC_CONST;
GType boxes_collection_filter_get_type (void) G_GNUC_CONST;
gboolean boxes_collection_filter_filter (BoxesCollectionFilter* self, BoxesCollectionItem* item);
void boxes_collection_view_refilter (BoxesCollectionView* self);
void boxes_collection_view_activate_first_item (BoxesCollectionView* self);
static void boxes_collection_view_setup_view (BoxesCollectionView* self);
static gint __lambda26_ (BoxesCollectionView* self, GtkTreeModel* store, GtkTreeIter* a, GtkTreeIter* b);
gint boxes_collection_item_compare (BoxesCollectionItem* self, BoxesCollectionItem* other);
static gint ___lambda26__gtk_tree_iter_compare_func (GtkTreeModel* model, GtkTreeIter* a, GtkTreeIter* b, gpointer self);
static void __lambda27_ (BoxesCollectionView* self);
static void ___lambda27__gtk_tree_model_row_deleted (GtkTreeModel* _sender, GtkTreePath* path, gpointer self);
static void __lambda28_ (BoxesCollectionView* self);
static void ___lambda28__gtk_tree_model_row_inserted (GtkTreeModel* _sender, GtkTreePath* path, GtkTreeIter* iter, gpointer self);
static gboolean _boxes_collection_view_model_visible_gtk_tree_model_filter_visible_func (GtkTreeModel* model, GtkTreeIter* iter, gpointer self);
static void __lambda29_ (BoxesCollectionView* self, GdMainView* view, const gchar* id, GtkTreePath* path);
GType boxes_libvirt_machine_get_type (void) G_GNUC_CONST;
gboolean boxes_libvirt_machine_get_importing (BoxesLibvirtMachine* self);
void boxes_app_window_select_item (BoxesAppWindow* self, BoxesCollectionItem* item);
static void ___lambda29__gd_main_view_item_activated (GdMainView* _sender, const gchar* object, GtkTreePath* p0, gpointer self);
static void __lambda44_ (BoxesCollectionView* self);
static void ___lambda44__gd_main_view_view_selection_changed (GdMainView* _sender, gpointer self);
void boxes_collection_view_select (BoxesCollectionView* self, BoxesSelectionCriteria selection);
static Block22Data* block22_data_ref (Block22Data* _data22_);
static void block22_data_unref (void * _userdata_);
void boxes_app_window_set_selection_mode (BoxesAppWindow* self, gboolean value);
static gboolean __lambda45_ (Block22Data* _data22_, GtkTreeModel* filter_model, GtkTreePath* filter_path, GtkTreeIter* filter_iter);
gboolean boxes_machine_is_running (BoxesMachine* self);
static gboolean ___lambda45__gtk_tree_model_foreach_func (GtkTreeModel* model, GtkTreePath* path, GtkTreeIter* iter, gpointer self);
static Block23Data* block23_data_ref (Block23Data* _data23_);
static void block23_data_unref (void * _userdata_);
gboolean boxes_machine_get_under_construction (BoxesMachine* self);
GType boxes_machine_machine_state_get_type (void) G_GNUC_CONST;
BoxesMachineMachineState boxes_machine_get_state (BoxesMachine* self);
static gboolean __lambda22_ (Block23Data* _data23_);
static gboolean ___lambda22__gsource_func (gpointer self);
static gboolean boxes_collection_view_launch_context_popover_for_path (BoxesCollectionView* self, GtkTreePath* path);
void boxes_actions_popover_update_for_item (BoxesActionsPopover* self, BoxesCollectionItem* item);
BoxesCollectionView* boxes_collection_view_new (void);
BoxesCollectionView* boxes_collection_view_construct (GType object_type);
BoxesCategory* boxes_collection_view_get_category (BoxesCollectionView* self);
void boxes_collection_view_set_category (BoxesCollectionView* self, BoxesCategory* value);
static GObject * boxes_collection_view_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
GType boxes_category_kind_get_type (void) G_GNUC_CONST;
BoxesCategory* boxes_category_new (const gchar* name, BoxesCategoryKind kind);
BoxesCategory* boxes_category_construct (GType object_type, const gchar* name, BoxesCategoryKind kind);
static void _boxes_collection_view_ui_state_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void boxes_collection_view_finalize (GObject* obj);
BoxesUIState boxes_ui_get_previous_ui_state (BoxesUI* self);
static void _vala_boxes_collection_view_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
void boxes_ui_set_previous_ui_state (BoxesUI* self, BoxesUIState value);
void boxes_ui_set_ui_state (BoxesUI* self, BoxesUIState value);
static void _vala_boxes_collection_view_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);


GType boxes_selection_criteria_get_type (void) {
	static volatile gsize boxes_selection_criteria_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_selection_criteria_type_id__volatile)) {
		static const GEnumValue values[] = {{BOXES_SELECTION_CRITERIA_ALL, "BOXES_SELECTION_CRITERIA_ALL", "all"}, {BOXES_SELECTION_CRITERIA_NONE, "BOXES_SELECTION_CRITERIA_NONE", "none"}, {BOXES_SELECTION_CRITERIA_RUNNING, "BOXES_SELECTION_CRITERIA_RUNNING", "running"}, {0, NULL, NULL}};
		GType boxes_selection_criteria_type_id;
		boxes_selection_criteria_type_id = g_enum_register_static ("BoxesSelectionCriteria", values);
		g_once_init_leave (&boxes_selection_criteria_type_id__volatile, boxes_selection_criteria_type_id);
	}
	return boxes_selection_criteria_type_id__volatile;
}


static GType boxes_collection_view_model_columns_get_type (void) {
	static volatile gsize boxes_collection_view_model_columns_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_collection_view_model_columns_type_id__volatile)) {
		static const GEnumValue values[] = {{BOXES_COLLECTION_VIEW_MODEL_COLUMNS_SCREENSHOT, "BOXES_COLLECTION_VIEW_MODEL_COLUMNS_SCREENSHOT", "screenshot"}, {BOXES_COLLECTION_VIEW_MODEL_COLUMNS_TITLE, "BOXES_COLLECTION_VIEW_MODEL_COLUMNS_TITLE", "title"}, {BOXES_COLLECTION_VIEW_MODEL_COLUMNS_INFO, "BOXES_COLLECTION_VIEW_MODEL_COLUMNS_INFO", "info"}, {BOXES_COLLECTION_VIEW_MODEL_COLUMNS_SELECTED, "BOXES_COLLECTION_VIEW_MODEL_COLUMNS_SELECTED", "selected"}, {BOXES_COLLECTION_VIEW_MODEL_COLUMNS_PULSE, "BOXES_COLLECTION_VIEW_MODEL_COLUMNS_PULSE", "pulse"}, {BOXES_COLLECTION_VIEW_MODEL_COLUMNS_ITEM, "BOXES_COLLECTION_VIEW_MODEL_COLUMNS_ITEM", "item"}, {BOXES_COLLECTION_VIEW_MODEL_COLUMNS_LAST, "BOXES_COLLECTION_VIEW_MODEL_COLUMNS_LAST", "last"}, {0, NULL, NULL}};
		GType boxes_collection_view_model_columns_type_id;
		boxes_collection_view_model_columns_type_id = g_enum_register_static ("BoxesCollectionViewModelColumns", values);
		g_once_init_leave (&boxes_collection_view_model_columns_type_id__volatile, boxes_collection_view_model_columns_type_id);
	}
	return boxes_collection_view_model_columns_type_id__volatile;
}


static void _g_object_unref0_ (gpointer var) {
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 525 "collection-view.c"
}


static void _g_list_free__g_object_unref0_ (GList* self) {
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_list_foreach (self, (GFunc) _g_object_unref0_, NULL);
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_list_free (self);
#line 534 "collection-view.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return self ? g_object_ref (self) : NULL;
#line 541 "collection-view.c"
}


static Block18Data* block18_data_ref (Block18Data* _data18_) {
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_atomic_int_inc (&_data18_->_ref_count_);
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return _data18_;
#line 550 "collection-view.c"
}


static void block18_data_unref (void * _userdata_) {
	Block18Data* _data18_;
	_data18_ = (Block18Data*) _userdata_;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (g_atomic_int_dec_and_test (&_data18_->_ref_count_)) {
#line 559 "collection-view.c"
		BoxesCollectionView* self;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		self = _data18_->self;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (_data18_->window);
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (self);
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		g_slice_free (Block18Data, _data18_);
#line 569 "collection-view.c"
	}
}


static void __lambda14_ (Block18Data* _data18_) {
	BoxesCollectionView* self;
	BoxesAppWindow* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
	BoxesAppWindow* _tmp3_ = NULL;
	gboolean _tmp4_ = FALSE;
	gboolean _tmp5_ = FALSE;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self = _data18_->self;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = _data18_->window;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = boxes_app_window_get_selection_mode (_tmp0_);
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = _tmp1_;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gd_main_view_set_selection_mode ((GdMainView*) self, _tmp2_);
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = _data18_->window;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp4_ = boxes_app_window_get_selection_mode (_tmp3_);
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp5_ = _tmp4_;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (!_tmp5_) {
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		gd_main_view_unselect_all ((GdMainView*) self);
#line 602 "collection-view.c"
	}
}


static void ___lambda14__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	__lambda14_ (self);
#line 610 "collection-view.c"
}


static gboolean _boxes_collection_view_on_button_press_event_gtk_widget_button_release_event (GtkWidget* _sender, GdkEventButton* event, gpointer self) {
	gboolean result;
	result = boxes_collection_view_on_button_press_event ((BoxesCollectionView*) self, event);
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 619 "collection-view.c"
}


static gboolean _boxes_collection_view_on_key_press_event_gtk_widget_key_press_event (GtkWidget* _sender, GdkEventKey* event, gpointer self) {
	gboolean result;
	result = boxes_collection_view_on_key_press_event ((BoxesCollectionView*) self, event);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 628 "collection-view.c"
}


void boxes_collection_view_setup_ui (BoxesCollectionView* self, BoxesAppWindow* window) {
	Block18Data* _data18_;
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesAppWindow* _tmp1_ = NULL;
	BoxesAppWindow* _tmp2_ = NULL;
	BoxesAppWindow* _tmp3_ = NULL;
	BoxesAppWindow* _tmp4_ = NULL;
	GtkIconView* icon_view = NULL;
	GtkWidget* _tmp5_ = NULL;
	GtkIconView* _tmp6_ = NULL;
	BoxesAppWindow* _tmp7_ = NULL;
	BoxesActionsPopover* _tmp8_ = NULL;
	BoxesActionsPopover* _tmp9_ = NULL;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (self != NULL);
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (window != NULL);
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data18_ = g_slice_new0 (Block18Data);
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data18_->_ref_count_ = 1;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data18_->self = g_object_ref (self);
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = window;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (_data18_->window);
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data18_->window = _tmp1_;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = _data18_->window;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (self->priv->window);
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self->priv->window = _tmp3_;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp4_ = _data18_->window;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_signal_connect_data ((GObject*) _tmp4_, "notify::selection-mode", (GCallback) ___lambda14__g_object_notify, block18_data_ref (_data18_), (GClosureNotify) block18_data_unref, 0);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp5_ = gd_main_view_get_generic_view ((GdMainView*) self);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp6_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, gtk_icon_view_get_type ()) ? ((GtkIconView*) _tmp5_) : NULL);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	icon_view = _tmp6_;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_signal_connect_object ((GtkWidget*) icon_view, "button-release-event", (GCallback) _boxes_collection_view_on_button_press_event_gtk_widget_button_release_event, self, 0);
#line 58 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_signal_connect_object ((GtkWidget*) icon_view, "key-press-event", (GCallback) _boxes_collection_view_on_key_press_event_gtk_widget_key_press_event, self, 0);
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp7_ = _data18_->window;
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp8_ = boxes_actions_popover_new (_tmp7_);
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_ref_sink (_tmp8_);
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (self->priv->context_popover);
#line 59 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self->priv->context_popover = _tmp8_;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp9_ = self->priv->context_popover;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_popover_set_relative_to ((GtkPopover*) _tmp9_, (GtkWidget*) icon_view);
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (icon_view);
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	block18_data_unref (_data18_);
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data18_ = NULL;
#line 705 "collection-view.c"
}


static void boxes_collection_view_ui_state_changed (BoxesCollectionView* self) {
	BoxesUIState _tmp0_ = 0;
	BoxesUIState _tmp1_ = 0;
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (self != NULL);
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = _tmp0_;
#line 64 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp1_ == BOXES_UI_STATE_COLLECTION) {
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		gd_main_view_unselect_all ((GdMainView*) self);
#line 722 "collection-view.c"
	}
}


static gboolean _vala_string_array_contains (gchar** stack, int stack_length, gchar* needle) {
	int i;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	for (i = 0; i < stack_length; i++) {
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		if (g_strcmp0 (stack[i], needle) == 0) {
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			return TRUE;
#line 735 "collection-view.c"
		}
	}
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return FALSE;
#line 740 "collection-view.c"
}


static void _vala_array_add3 (GIcon*** array, int* length, int* size, GIcon* value) {
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if ((*length) == (*size)) {
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		*array = g_renew (GIcon*, *array, (*size) + 1);
#line 751 "collection-view.c"
	}
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	(*array)[(*length)++] = value;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	(*array)[*length] = NULL;
#line 757 "collection-view.c"
}


static void boxes_collection_view_update_screenshot (BoxesCollectionView* self, GtkTreeIter* iter) {
	BoxesCollectionItem* item = NULL;
	GIcon** emblem_icons = NULL;
	GIcon** _tmp0_ = NULL;
	gint emblem_icons_length1 = 0;
	gint _emblem_icons_size_ = 0;
	GtkListStore* _tmp1_ = NULL;
	GtkTreeIter _tmp2_ = {0};
	BoxesMachine* machine = NULL;
	BoxesCollectionItem* _tmp3_ = NULL;
	BoxesMachine* _tmp4_ = NULL;
	BoxesMachine* _tmp5_ = NULL;
	GdkPixbuf* pixbuf = NULL;
	BoxesMachine* _tmp6_ = NULL;
	GdkPixbuf* _tmp7_ = NULL;
	GdkPixbuf* _tmp8_ = NULL;
	GdkPixbuf* _tmp9_ = NULL;
	BoxesMachine* _tmp10_ = NULL;
	BoxesBoxConfig* _tmp11_ = NULL;
	gchar** _tmp12_ = NULL;
	gint _tmp12__length1 = 0;
	gchar** _tmp13_ = NULL;
	gint _tmp13__length1 = 0;
	gchar** _tmp14_ = NULL;
	gint _tmp14__length1 = 0;
	gboolean _tmp15_ = FALSE;
	GIcon** _tmp18_ = NULL;
	gint _tmp18__length1 = 0;
	GtkListStore* _tmp48_ = NULL;
	GtkTreeIter _tmp49_ = {0};
	GdkPixbuf* _tmp50_ = NULL;
	GError * _inner_error_ = NULL;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (self != NULL);
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (iter != NULL);
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = g_new0 (GIcon*, 0 + 1);
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	emblem_icons = _tmp0_;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	emblem_icons_length1 = 0;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_emblem_icons_size_ = emblem_icons_length1;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = self->priv->store;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = *iter;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_tree_model_get ((GtkTreeModel*) _tmp1_, &_tmp2_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_ITEM, &item, -1);
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = item;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp4_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp3_) : NULL);
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	machine = _tmp4_;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp5_ = machine;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (_tmp5_ != NULL);
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp6_ = machine;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp7_ = boxes_machine_get_pixbuf (_tmp6_);
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp8_ = _tmp7_;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp9_ = _g_object_ref0 (_tmp8_);
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	pixbuf = _tmp9_;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp10_ = machine;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp11_ = _tmp10_->config;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp12_ = boxes_box_config_get_categories (_tmp11_, &_tmp12__length1);
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp13_ = _tmp12_;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp13__length1 = _tmp12__length1;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp14_ = _tmp13_;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp14__length1 = _tmp13__length1;
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp15_ = _vala_string_array_contains (_tmp14_, _tmp13__length1, "favorite");
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp14_ = (_vala_array_free (_tmp14_, _tmp14__length1, (GDestroyNotify) g_free), NULL);
#line 77 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp15_) {
#line 851 "collection-view.c"
		GIcon** _tmp16_ = NULL;
		gint _tmp16__length1 = 0;
		GIcon* _tmp17_ = NULL;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp16_ = emblem_icons;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp16__length1 = emblem_icons_length1;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp17_ = boxes_create_symbolic_emblem ("emblem-favorite");
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_vala_array_add3 (&emblem_icons, &emblem_icons_length1, &_emblem_icons_size_, _tmp17_);
#line 863 "collection-view.c"
	}
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp18_ = emblem_icons;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp18__length1 = emblem_icons_length1;
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp18__length1 > 0) {
#line 871 "collection-view.c"
		GEmblemedIcon* emblemed_icon = NULL;
		GdkPixbuf* _tmp19_ = NULL;
		GEmblemedIcon* _tmp20_ = NULL;
		GIcon** _tmp21_ = NULL;
		gint _tmp21__length1 = 0;
		GtkIconTheme* theme = NULL;
		GtkIconTheme* _tmp27_ = NULL;
		GtkIconTheme* _tmp28_ = NULL;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp19_ = pixbuf;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp20_ = (GEmblemedIcon*) g_emblemed_icon_new ((GIcon*) _tmp19_, NULL);
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		emblemed_icon = _tmp20_;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp21_ = emblem_icons;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp21__length1 = emblem_icons_length1;
#line 890 "collection-view.c"
		{
			GIcon** emblem_icon_collection = NULL;
			gint emblem_icon_collection_length1 = 0;
			gint _emblem_icon_collection_size_ = 0;
			gint emblem_icon_it = 0;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			emblem_icon_collection = _tmp21_;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			emblem_icon_collection_length1 = _tmp21__length1;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			for (emblem_icon_it = 0; emblem_icon_it < _tmp21__length1; emblem_icon_it = emblem_icon_it + 1) {
#line 902 "collection-view.c"
				GIcon* _tmp22_ = NULL;
				GIcon* emblem_icon = NULL;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
				_tmp22_ = _g_object_ref0 (emblem_icon_collection[emblem_icon_it]);
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
				emblem_icon = _tmp22_;
#line 909 "collection-view.c"
				{
					GEmblemedIcon* _tmp23_ = NULL;
					GIcon* _tmp24_ = NULL;
					GEmblem* _tmp25_ = NULL;
					GEmblem* _tmp26_ = NULL;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
					_tmp23_ = emblemed_icon;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
					_tmp24_ = emblem_icon;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
					_tmp25_ = g_emblem_new (_tmp24_);
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
					_tmp26_ = _tmp25_;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
					g_emblemed_icon_add_emblem (_tmp23_, _tmp26_);
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
					_g_object_unref0 (_tmp26_);
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
					_g_object_unref0 (emblem_icon);
#line 929 "collection-view.c"
				}
			}
		}
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp27_ = gtk_icon_theme_get_default ();
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp28_ = _g_object_ref0 (_tmp27_);
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		theme = _tmp28_;
#line 939 "collection-view.c"
		{
			gint size = 0;
			GdkPixbuf* _tmp29_ = NULL;
			gint _tmp30_ = 0;
			gint _tmp31_ = 0;
			GdkPixbuf* _tmp32_ = NULL;
			gint _tmp33_ = 0;
			gint _tmp34_ = 0;
			gint _tmp35_ = 0;
			GtkIconInfo* icon_info = NULL;
			GtkIconTheme* _tmp36_ = NULL;
			GEmblemedIcon* _tmp37_ = NULL;
			gint _tmp38_ = 0;
			GtkIconInfo* _tmp39_ = NULL;
			GdkPixbuf* _tmp40_ = NULL;
			GtkIconInfo* _tmp41_ = NULL;
			GdkPixbuf* _tmp42_ = NULL;
			GdkPixbuf* _tmp43_ = NULL;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp29_ = pixbuf;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp30_ = gdk_pixbuf_get_width (_tmp29_);
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp31_ = _tmp30_;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp32_ = pixbuf;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp33_ = gdk_pixbuf_get_height (_tmp32_);
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp34_ = _tmp33_;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp35_ = MAX (_tmp31_, _tmp34_);
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			size = _tmp35_;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp36_ = theme;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp37_ = emblemed_icon;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp38_ = size;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp39_ = gtk_icon_theme_lookup_by_gicon (_tmp36_, (GIcon*) _tmp37_, _tmp38_, GTK_ICON_LOOKUP_FORCE_SIZE);
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			icon_info = _tmp39_;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp41_ = icon_info;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp42_ = gtk_icon_info_load_icon (_tmp41_, &_inner_error_);
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp40_ = _tmp42_;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
				_gtk_icon_info_free0 (icon_info);
#line 994 "collection-view.c"
				goto __catch7_g_error;
			}
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp43_ = _tmp40_;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp40_ = NULL;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_g_object_unref0 (pixbuf);
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			pixbuf = _tmp43_;
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_g_object_unref0 (_tmp40_);
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_gtk_icon_info_free0 (icon_info);
#line 1009 "collection-view.c"
		}
		goto __finally7;
		__catch7_g_error:
		{
			GError* _error_ = NULL;
			GError* _tmp44_ = NULL;
			const gchar* _tmp45_ = NULL;
			gchar* _tmp46_ = NULL;
			gchar* _tmp47_ = NULL;
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_error_ = _inner_error_;
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_inner_error_ = NULL;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp44_ = _error_;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp45_ = _tmp44_->message;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp46_ = g_strconcat ("Unable to render the emblem: ", _tmp45_, NULL);
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp47_ = _tmp46_;
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			g_warning ("collection-view.vala:93: %s", _tmp47_);
#line 93 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_g_free0 (_tmp47_);
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_g_error_free0 (_error_);
#line 1037 "collection-view.c"
		}
		__finally7:
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_g_object_unref0 (theme);
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_g_object_unref0 (emblemed_icon);
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_g_object_unref0 (pixbuf);
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_g_object_unref0 (machine);
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			emblem_icons = (_vala_array_free (emblem_icons, emblem_icons_length1, (GDestroyNotify) g_object_unref), NULL);
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_g_object_unref0 (item);
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			g_clear_error (&_inner_error_);
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			return;
#line 1060 "collection-view.c"
		}
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (theme);
#line 80 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (emblemed_icon);
#line 1066 "collection-view.c"
	}
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp48_ = self->priv->store;
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp49_ = *iter;
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp50_ = pixbuf;
#line 97 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_list_store_set (_tmp48_, &_tmp49_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_SCREENSHOT, _tmp50_, -1);
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_widget_queue_draw ((GtkWidget*) self);
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (pixbuf);
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (machine);
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	emblem_icons = (_vala_array_free (emblem_icons, emblem_icons_length1, (GDestroyNotify) g_object_unref), NULL);
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (item);
#line 1086 "collection-view.c"
}


static GtkTreeIter* _gtk_tree_iter_dup (GtkTreeIter* self) {
	GtkTreeIter* dup;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	dup = g_new0 (GtkTreeIter, 1);
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	memcpy (dup, self, sizeof (GtkTreeIter));
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return dup;
#line 1098 "collection-view.c"
}


static gpointer __gtk_tree_iter_dup0 (gpointer self) {
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return self ? _gtk_tree_iter_dup (self) : NULL;
#line 1105 "collection-view.c"
}


static void boxes_collection_view_append (BoxesCollectionView* self, const gchar* title, const gchar* info, BoxesCollectionItem* item, GtkTreeIter* result) {
	GtkTreeIter iter = {0};
	GtkListStore* _tmp0_ = NULL;
	GtkTreeIter _tmp1_ = {0};
	GtkListStore* _tmp2_ = NULL;
	GtkTreeIter _tmp3_ = {0};
	BoxesCollectionItem* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	GtkListStore* _tmp7_ = NULL;
	GtkTreeIter _tmp8_ = {0};
	const gchar* _tmp9_ = NULL;
	const gchar* _tmp10_ = NULL;
	GtkListStore* _tmp14_ = NULL;
	GtkTreeIter _tmp15_ = {0};
	GtkListStore* _tmp16_ = NULL;
	GtkTreeIter _tmp17_ = {0};
	BoxesCollectionItem* _tmp18_ = NULL;
	GtkTreeIter _tmp19_ = {0};
	BoxesCollectionItem* _tmp20_ = NULL;
	GtkTreeIter _tmp21_ = {0};
	GtkTreeIter* _tmp22_ = NULL;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (self != NULL);
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (title != NULL);
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (item != NULL);
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->priv->store;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_list_store_append (_tmp0_, &_tmp1_);
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	iter = _tmp1_;
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = self->priv->store;
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = iter;
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp4_ = item;
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp5_ = g_strdup_printf ("%p", _tmp4_);
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp6_ = _tmp5_;
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_list_store_set (_tmp2_, &_tmp3_, GD_MAIN_COLUMN_ID, _tmp6_, -1);
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_free0 (_tmp6_);
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp7_ = self->priv->store;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp8_ = iter;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp9_ = title;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_list_store_set (_tmp7_, &_tmp8_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_TITLE, _tmp9_, -1);
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp10_ = info;
#line 109 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp10_ != NULL) {
#line 1169 "collection-view.c"
		GtkListStore* _tmp11_ = NULL;
		GtkTreeIter _tmp12_ = {0};
		const gchar* _tmp13_ = NULL;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp11_ = self->priv->store;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp12_ = iter;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp13_ = info;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		gtk_list_store_set (_tmp11_, &_tmp12_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_INFO, _tmp13_, -1);
#line 1181 "collection-view.c"
	}
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp14_ = self->priv->store;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp15_ = iter;
#line 111 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_list_store_set (_tmp14_, &_tmp15_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_SELECTED, FALSE, -1);
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp16_ = self->priv->store;
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp17_ = iter;
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp18_ = item;
#line 112 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_list_store_set (_tmp16_, &_tmp17_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_ITEM, _tmp18_, -1);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp19_ = iter;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	boxes_collection_view_update_screenshot (self, &_tmp19_);
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp20_ = item;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp21_ = iter;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp22_ = __gtk_tree_iter_dup0 (&_tmp21_);
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_set_data_full ((GObject*) _tmp20_, "iter", _tmp22_, g_free);
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	*result = iter;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return;
#line 1213 "collection-view.c"
}


static Block19Data* block19_data_ref (Block19Data* _data19_) {
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_atomic_int_inc (&_data19_->_ref_count_);
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return _data19_;
#line 1222 "collection-view.c"
}


static void block19_data_unref (void * _userdata_) {
	Block19Data* _data19_;
	_data19_ = (Block19Data*) _userdata_;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (g_atomic_int_dec_and_test (&_data19_->_ref_count_)) {
#line 1231 "collection-view.c"
		BoxesCollectionView* self;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		self = _data19_->self;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (_data19_->window);
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (_data19_->machine);
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (_data19_->item);
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (self);
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		g_slice_free (Block19Data, _data19_);
#line 1245 "collection-view.c"
	}
}


static Block20Data* block20_data_ref (Block20Data* _data20_) {
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_atomic_int_inc (&_data20_->_ref_count_);
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return _data20_;
#line 1255 "collection-view.c"
}


static void block20_data_unref (void * _userdata_) {
	Block20Data* _data20_;
	_data20_ = (Block20Data*) _userdata_;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (g_atomic_int_dec_and_test (&_data20_->_ref_count_)) {
#line 1264 "collection-view.c"
		BoxesCollectionView* self;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		self = _data20_->_data19_->self;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		block19_data_unref (_data20_->_data19_);
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_data20_->_data19_ = NULL;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		g_slice_free (Block20Data, _data20_);
#line 1274 "collection-view.c"
	}
}


static void ___lambda17_ (Block20Data* _data20_) {
	Block19Data* _data19_;
	BoxesCollectionView* self;
	BoxesAppWindow* _tmp0_ = NULL;
	BoxesUIState _tmp1_ = 0;
	BoxesUIState _tmp2_ = 0;
	GList* _tmp3_ = NULL;
	BoxesCollectionItem* _tmp4_ = NULL;
	GList* _tmp5_ = NULL;
	BoxesAppWindow* _tmp8_ = NULL;
	gulong _tmp9_ = 0UL;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data19_ = _data20_->_data19_;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self = _data19_->self;
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = _data19_->window;
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = boxes_ui_get_ui_state ((BoxesUI*) _tmp0_);
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = _tmp1_;
#line 136 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp2_ == BOXES_UI_STATE_WIZARD) {
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		return;
#line 1304 "collection-view.c"
	}
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = self->priv->hidden_items;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp4_ = _data19_->item;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp5_ = g_list_find (_tmp3_, _tmp4_);
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp5_ != NULL) {
#line 1314 "collection-view.c"
		BoxesCollectionItem* _tmp6_ = NULL;
		BoxesCollectionItem* _tmp7_ = NULL;
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp6_ = _data19_->item;
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		boxes_collection_view_add_item (self, _tmp6_);
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp7_ = _data19_->item;
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		self->priv->hidden_items = g_list_remove (self->priv->hidden_items, _tmp7_);
#line 1325 "collection-view.c"
	}
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp8_ = _data19_->window;
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp9_ = _data20_->ui_state_id;
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_signal_handler_disconnect ((GObject*) _tmp8_, _tmp9_);
#line 1333 "collection-view.c"
}


static void ____lambda17__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	___lambda17_ (self);
#line 1340 "collection-view.c"
}


static void __lambda18_ (Block19Data* _data19_) {
	BoxesCollectionView* self;
	GtkTreeIter _tmp0_ = {0};
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self = _data19_->self;
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = _data19_->iter;
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	boxes_collection_view_update_screenshot (self, &_tmp0_);
#line 1353 "collection-view.c"
}


static void ___lambda18__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	__lambda18_ (self);
#line 1360 "collection-view.c"
}


static void __lambda19_ (Block19Data* _data19_) {
	BoxesCollectionView* self;
	GtkTreeIter _tmp0_ = {0};
#line 156 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self = _data19_->self;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = _data19_->iter;
#line 158 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	boxes_collection_view_update_screenshot (self, &_tmp0_);
#line 1373 "collection-view.c"
}


static void ___lambda19__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 156 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	__lambda19_ (self);
#line 1380 "collection-view.c"
}


static void __lambda20_ (Block19Data* _data19_) {
	BoxesCollectionView* self;
	GtkListStore* _tmp0_ = NULL;
	GtkTreeIter _tmp1_ = {0};
	BoxesCollectionItem* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self = _data19_->self;
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->priv->store;
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = _data19_->iter;
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = _data19_->item;
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = boxes_collection_item_get_name (_tmp2_);
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp4_ = _tmp3_;
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_list_store_set (_tmp0_, &_tmp1_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_TITLE, _tmp4_, -1);
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_widget_queue_draw ((GtkWidget*) self);
#line 1407 "collection-view.c"
}


static void ___lambda20__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	__lambda20_ (self);
#line 1414 "collection-view.c"
}


static void __lambda21_ (Block19Data* _data19_) {
	BoxesCollectionView* self;
	GtkListStore* _tmp0_ = NULL;
	GtkTreeIter _tmp1_ = {0};
	BoxesMachine* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self = _data19_->self;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->priv->store;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = _data19_->iter;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = _data19_->machine;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = boxes_machine_get_info (_tmp2_);
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp4_ = _tmp3_;
#line 171 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_list_store_set (_tmp0_, &_tmp1_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_INFO, _tmp4_, -1);
#line 172 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_widget_queue_draw ((GtkWidget*) self);
#line 1441 "collection-view.c"
}


static void ___lambda21__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	__lambda21_ (self);
#line 1448 "collection-view.c"
}


static void __lambda23_ (Block19Data* _data19_) {
	BoxesCollectionView* self;
	GtkTreeIter _tmp0_ = {0};
	BoxesMachine* _tmp1_ = NULL;
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self = _data19_->self;
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = _data19_->iter;
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = _data19_->machine;
#line 179 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	boxes_collection_view_setup_activity (self, &_tmp0_, _tmp1_);
#line 180 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_widget_queue_draw ((GtkWidget*) self);
#line 1466 "collection-view.c"
}


static void ___lambda23__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	__lambda23_ (self);
#line 1473 "collection-view.c"
}


static void __lambda24_ (Block19Data* _data19_) {
	BoxesCollectionView* self;
	GtkTreeIter _tmp0_ = {0};
	BoxesMachine* _tmp1_ = NULL;
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self = _data19_->self;
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = _data19_->iter;
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = _data19_->machine;
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	boxes_collection_view_setup_activity (self, &_tmp0_, _tmp1_);
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_widget_queue_draw ((GtkWidget*) self);
#line 1491 "collection-view.c"
}


static void ___lambda24__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	__lambda24_ (self);
#line 1498 "collection-view.c"
}


void boxes_collection_view_add_item (BoxesCollectionView* self, BoxesCollectionItem* item) {
	Block19Data* _data19_;
	BoxesCollectionItem* _tmp0_ = NULL;
	BoxesCollectionItem* _tmp1_ = NULL;
	BoxesCollectionItem* _tmp2_ = NULL;
	BoxesMachine* _tmp3_ = NULL;
	BoxesMachine* _tmp4_ = NULL;
	BoxesMachine* _tmp7_ = NULL;
	BoxesAppWindow* _tmp8_ = NULL;
	BoxesAppWindow* _tmp9_ = NULL;
	BoxesAppWindow* _tmp10_ = NULL;
	BoxesAppWindow* _tmp11_ = NULL;
	BoxesUIState _tmp12_ = 0;
	BoxesUIState _tmp13_ = 0;
	BoxesMachine* _tmp18_ = NULL;
	const gchar* _tmp19_ = NULL;
	const gchar* _tmp20_ = NULL;
	BoxesMachine* _tmp21_ = NULL;
	const gchar* _tmp22_ = NULL;
	const gchar* _tmp23_ = NULL;
	BoxesCollectionItem* _tmp24_ = NULL;
	GtkTreeIter _tmp25_ = {0};
	gulong pixbuf_id = 0UL;
	BoxesMachine* _tmp26_ = NULL;
	gulong _tmp27_ = 0UL;
	BoxesCollectionItem* _tmp28_ = NULL;
	gulong _tmp29_ = 0UL;
	gulong categories_id = 0UL;
	BoxesMachine* _tmp30_ = NULL;
	BoxesBoxConfig* _tmp31_ = NULL;
	gulong _tmp32_ = 0UL;
	BoxesCollectionItem* _tmp33_ = NULL;
	gulong _tmp34_ = 0UL;
	gulong name_id = 0UL;
	BoxesCollectionItem* _tmp35_ = NULL;
	gulong _tmp36_ = 0UL;
	BoxesCollectionItem* _tmp37_ = NULL;
	gulong _tmp38_ = 0UL;
	gulong info_id = 0UL;
	BoxesMachine* _tmp39_ = NULL;
	gulong _tmp40_ = 0UL;
	BoxesCollectionItem* _tmp41_ = NULL;
	gulong _tmp42_ = 0UL;
	GtkTreeIter _tmp43_ = {0};
	BoxesMachine* _tmp44_ = NULL;
	gulong under_construct_id = 0UL;
	BoxesMachine* _tmp45_ = NULL;
	gulong _tmp46_ = 0UL;
	BoxesCollectionItem* _tmp47_ = NULL;
	gulong _tmp48_ = 0UL;
	gulong machine_state_id = 0UL;
	BoxesMachine* _tmp49_ = NULL;
	gulong _tmp50_ = 0UL;
	BoxesCollectionItem* _tmp51_ = NULL;
	gulong _tmp52_ = 0UL;
	BoxesCollectionItem* _tmp53_ = NULL;
	BoxesAppWindow* _tmp54_ = NULL;
	BoxesUIState _tmp55_ = 0;
	BoxesUIState _tmp56_ = 0;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (self != NULL);
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (item != NULL);
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data19_ = g_slice_new0 (Block19Data);
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data19_->_ref_count_ = 1;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data19_->self = g_object_ref (self);
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = item;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (_data19_->item);
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data19_->item = _tmp1_;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = _data19_->item;
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp2_) : NULL);
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data19_->machine = _tmp3_;
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp4_ = _data19_->machine;
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp4_ == NULL) {
#line 1589 "collection-view.c"
		gchar* _tmp5_ = NULL;
		gchar* _tmp6_ = NULL;
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp5_ = g_strdup_printf ("Cannot add item %p", &_data19_->item);
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp6_ = _tmp5_;
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		g_warning ("collection-view.vala:124: %s", _tmp6_);
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_free0 (_tmp6_);
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		block19_data_unref (_data19_);
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_data19_ = NULL;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		return;
#line 1606 "collection-view.c"
	}
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp7_ = _data19_->machine;
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp8_ = boxes_machine_get_window (_tmp7_);
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp9_ = _tmp8_;
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp10_ = _g_object_ref0 (_tmp9_);
#line 128 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data19_->window = _tmp10_;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp11_ = _data19_->window;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp12_ = boxes_ui_get_ui_state ((BoxesUI*) _tmp11_);
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp13_ = _tmp12_;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp13_ == BOXES_UI_STATE_WIZARD) {
#line 1626 "collection-view.c"
		Block20Data* _data20_;
		BoxesCollectionItem* _tmp14_ = NULL;
		BoxesCollectionItem* _tmp15_ = NULL;
		BoxesAppWindow* _tmp16_ = NULL;
		gulong _tmp17_ = 0UL;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_data20_ = g_slice_new0 (Block20Data);
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_data20_->_ref_count_ = 1;
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_data20_->_data19_ = block19_data_ref (_data19_);
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp14_ = _data19_->item;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp15_ = _g_object_ref0 (_tmp14_);
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		self->priv->hidden_items = g_list_append (self->priv->hidden_items, _tmp15_);
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_data20_->ui_state_id = (gulong) 0;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp16_ = _data19_->window;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp17_ = g_signal_connect_data ((GObject*) _tmp16_, "notify::ui-state", (GCallback) ____lambda17__g_object_notify, block20_data_ref (_data20_), (GClosureNotify) block20_data_unref, 0);
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_data20_->ui_state_id = _tmp17_;
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		block20_data_unref (_data20_);
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_data20_ = NULL;
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		block19_data_unref (_data19_);
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_data19_ = NULL;
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		return;
#line 1662 "collection-view.c"
	}
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp18_ = _data19_->machine;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp19_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp18_);
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp20_ = _tmp19_;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp21_ = _data19_->machine;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp22_ = boxes_machine_get_info (_tmp21_);
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp23_ = _tmp22_;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp24_ = _data19_->item;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	boxes_collection_view_append (self, _tmp20_, _tmp23_, _tmp24_, &_tmp25_);
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data19_->iter = _tmp25_;
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp26_ = _data19_->machine;
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp27_ = g_signal_connect_data ((GObject*) _tmp26_, "notify::pixbuf", (GCallback) ___lambda18__g_object_notify, block19_data_ref (_data19_), (GClosureNotify) block19_data_unref, 0);
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	pixbuf_id = _tmp27_;
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp28_ = _data19_->item;
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp29_ = pixbuf_id;
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_set_data_full ((GObject*) _tmp28_, "pixbuf_id", (gpointer) ((guintptr) _tmp29_), NULL);
#line 156 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp30_ = _data19_->machine;
#line 156 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp31_ = _tmp30_->config;
#line 156 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp32_ = g_signal_connect_data ((GObject*) _tmp31_, "notify::categories", (GCallback) ___lambda19__g_object_notify, block19_data_ref (_data19_), (GClosureNotify) block19_data_unref, 0);
#line 156 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	categories_id = _tmp32_;
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp33_ = _data19_->item;
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp34_ = categories_id;
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_set_data_full ((GObject*) _tmp33_, "categories_id", (gpointer) ((guintptr) _tmp34_), NULL);
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp35_ = _data19_->item;
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp36_ = g_signal_connect_data ((GObject*) _tmp35_, "notify::name", (GCallback) ___lambda20__g_object_notify, block19_data_ref (_data19_), (GClosureNotify) block19_data_unref, 0);
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	name_id = _tmp36_;
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp37_ = _data19_->item;
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp38_ = name_id;
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_set_data_full ((GObject*) _tmp37_, "name_id", (gpointer) ((guintptr) _tmp38_), NULL);
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp39_ = _data19_->machine;
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp40_ = g_signal_connect_data ((GObject*) _tmp39_, "notify::info", (GCallback) ___lambda21__g_object_notify, block19_data_ref (_data19_), (GClosureNotify) block19_data_unref, 0);
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	info_id = _tmp40_;
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp41_ = _data19_->item;
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp42_ = info_id;
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_set_data_full ((GObject*) _tmp41_, "info_id", (gpointer) ((guintptr) _tmp42_), NULL);
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp43_ = _data19_->iter;
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp44_ = _data19_->machine;
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	boxes_collection_view_setup_activity (self, &_tmp43_, _tmp44_);
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp45_ = _data19_->machine;
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp46_ = g_signal_connect_data ((GObject*) _tmp45_, "notify::under-construction", (GCallback) ___lambda23__g_object_notify, block19_data_ref (_data19_), (GClosureNotify) block19_data_unref, 0);
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	under_construct_id = _tmp46_;
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp47_ = _data19_->item;
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp48_ = under_construct_id;
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_set_data_full ((GObject*) _tmp47_, "under_construct_id", (gpointer) ((guintptr) _tmp48_), NULL);
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp49_ = _data19_->machine;
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp50_ = g_signal_connect_data ((GObject*) _tmp49_, "notify::state", (GCallback) ___lambda24__g_object_notify, block19_data_ref (_data19_), (GClosureNotify) block19_data_unref, 0);
#line 183 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	machine_state_id = _tmp50_;
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp51_ = _data19_->item;
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp52_ = machine_state_id;
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_set_data_full ((GObject*) _tmp51_, "machine_state_id", (gpointer) ((guintptr) _tmp52_), NULL);
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp53_ = _data19_->item;
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp54_ = _data19_->window;
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp55_ = boxes_ui_get_ui_state ((BoxesUI*) _tmp54_);
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp56_ = _tmp55_;
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	boxes_ui_set_state ((BoxesUI*) _tmp53_, _tmp56_);
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	block19_data_unref (_data19_);
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data19_ = NULL;
#line 1776 "collection-view.c"
}


static Block21Data* block21_data_ref (Block21Data* _data21_) {
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_atomic_int_inc (&_data21_->_ref_count_);
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return _data21_;
#line 1785 "collection-view.c"
}


static void block21_data_unref (void * _userdata_) {
	Block21Data* _data21_;
	_data21_ = (Block21Data*) _userdata_;
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (g_atomic_int_dec_and_test (&_data21_->_ref_count_)) {
#line 1794 "collection-view.c"
		BoxesCollectionView* self;
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		self = _data21_->self;
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		__g_list_free__g_object_unref0_0 (_data21_->selected);
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (self);
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		g_slice_free (Block21Data, _data21_);
#line 1804 "collection-view.c"
	}
}


static gboolean __lambda25_ (Block21Data* _data21_, GtkTreeModel* store, GtkTreePath* path, GtkTreeIter* iter) {
	BoxesCollectionView* self;
	gboolean result = FALSE;
	BoxesCollectionItem* item = NULL;
	gboolean is_selected = FALSE;
	GtkTreeModel* _tmp0_ = NULL;
	GtkTreeIter _tmp1_ = {0};
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_ = FALSE;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self = _data21_->self;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (store != NULL, FALSE);
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (path != NULL, FALSE);
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (iter != NULL, FALSE);
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = store;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = *iter;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_tree_model_get (_tmp0_, &_tmp1_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_SELECTED, &is_selected, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_ITEM, &item, -1);
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = is_selected;
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp3_) {
#line 1836 "collection-view.c"
		BoxesCollectionItem* _tmp4_ = NULL;
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp4_ = item;
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp2_ = _tmp4_ != NULL;
#line 1842 "collection-view.c"
	} else {
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp2_ = FALSE;
#line 1846 "collection-view.c"
	}
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp2_) {
#line 1850 "collection-view.c"
		BoxesCollectionItem* _tmp5_ = NULL;
		BoxesCollectionItem* _tmp6_ = NULL;
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp5_ = item;
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp6_ = _g_object_ref0 (_tmp5_);
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_data21_->selected = g_list_append (_data21_->selected, _tmp6_);
#line 1859 "collection-view.c"
	}
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	result = FALSE;
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (item);
#line 206 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 1867 "collection-view.c"
}


static gboolean ___lambda25__gtk_tree_model_foreach_func (GtkTreeModel* model, GtkTreePath* path, GtkTreeIter* iter, gpointer self) {
	gboolean result;
	result = __lambda25_ (self, model, path, iter);
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 1876 "collection-view.c"
}


GList* boxes_collection_view_get_selected_items (BoxesCollectionView* self) {
	GList* result = NULL;
	Block21Data* _data21_;
	GtkListStore* _tmp0_ = NULL;
	GList* _tmp1_ = NULL;
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data21_ = g_slice_new0 (Block21Data);
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data21_->_ref_count_ = 1;
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data21_->self = g_object_ref (self);
#line 194 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data21_->selected = NULL;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->priv->store;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_tree_model_foreach ((GtkTreeModel*) _tmp0_, ___lambda25__gtk_tree_model_foreach_func, _data21_);
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = _data21_->selected;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data21_->selected = NULL;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	result = _tmp1_;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	block21_data_unref (_data21_);
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data21_ = NULL;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 1911 "collection-view.c"
}


void boxes_collection_view_remove_item (BoxesCollectionView* self, BoxesCollectionItem* item) {
	BoxesCollectionItem* _tmp0_ = NULL;
	GtkTreeIter* iter = NULL;
	BoxesCollectionItem* _tmp1_ = NULL;
	gconstpointer _tmp2_ = NULL;
	GtkTreeIter* _tmp3_ = NULL;
	GtkTreeIter* _tmp4_ = NULL;
	GtkListStore* _tmp5_ = NULL;
	GtkTreeIter* _tmp6_ = NULL;
	GtkTreeIter _tmp7_ = {0};
	BoxesCollectionItem* _tmp8_ = NULL;
	gulong pixbuf_id = 0UL;
	BoxesCollectionItem* _tmp9_ = NULL;
	gconstpointer _tmp10_ = NULL;
	BoxesCollectionItem* _tmp11_ = NULL;
	gulong _tmp12_ = 0UL;
	gulong name_id = 0UL;
	BoxesCollectionItem* _tmp13_ = NULL;
	gconstpointer _tmp14_ = NULL;
	BoxesCollectionItem* _tmp15_ = NULL;
	gulong _tmp16_ = 0UL;
	gulong info_id = 0UL;
	BoxesCollectionItem* _tmp17_ = NULL;
	gconstpointer _tmp18_ = NULL;
	BoxesCollectionItem* _tmp19_ = NULL;
	gulong _tmp20_ = 0UL;
	gulong under_construct_id = 0UL;
	BoxesCollectionItem* _tmp21_ = NULL;
	gconstpointer _tmp22_ = NULL;
	BoxesCollectionItem* _tmp23_ = NULL;
	gulong _tmp24_ = 0UL;
	gulong machine_state_id = 0UL;
	BoxesCollectionItem* _tmp25_ = NULL;
	gconstpointer _tmp26_ = NULL;
	gulong _tmp27_ = 0UL;
	BoxesCollectionItem* _tmp30_ = NULL;
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (self != NULL);
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (item != NULL);
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = item;
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self->priv->hidden_items = g_list_remove (self->priv->hidden_items, _tmp0_);
#line 215 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = item;
#line 215 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = g_object_get_data ((GObject*) _tmp1_, "iter");
#line 215 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = __gtk_tree_iter_dup0 ((GtkTreeIter*) _tmp2_);
#line 215 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	iter = _tmp3_;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp4_ = iter;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp4_ == NULL) {
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		g_debug ("collection-view.vala:217: item not in view or already removed");
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_free0 (iter);
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		return;
#line 1977 "collection-view.c"
	}
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp5_ = self->priv->store;
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp6_ = iter;
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp7_ = *_tmp6_;
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_list_store_remove (_tmp5_, &_tmp7_);
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp8_ = item;
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_set_data_full ((GObject*) _tmp8_, "iter", NULL, g_free);
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp9_ = item;
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp10_ = g_object_get_data ((GObject*) _tmp9_, "pixbuf_id");
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	pixbuf_id = (gulong) ((guintptr) _tmp10_);
#line 225 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp11_ = item;
#line 225 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp12_ = pixbuf_id;
#line 225 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_signal_handler_disconnect ((GObject*) _tmp11_, _tmp12_);
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp13_ = item;
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp14_ = g_object_get_data ((GObject*) _tmp13_, "name_id");
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	name_id = (gulong) ((guintptr) _tmp14_);
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp15_ = item;
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp16_ = name_id;
#line 227 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_signal_handler_disconnect ((GObject*) _tmp15_, _tmp16_);
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp17_ = item;
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp18_ = g_object_get_data ((GObject*) _tmp17_, "info_id");
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	info_id = (gulong) ((guintptr) _tmp18_);
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp19_ = item;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp20_ = info_id;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_signal_handler_disconnect ((GObject*) _tmp19_, _tmp20_);
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp21_ = item;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp22_ = g_object_get_data ((GObject*) _tmp21_, "under_construct_id");
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	under_construct_id = (gulong) ((guintptr) _tmp22_);
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp23_ = item;
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp24_ = under_construct_id;
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_signal_handler_disconnect ((GObject*) _tmp23_, _tmp24_);
#line 232 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp25_ = item;
#line 232 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp26_ = g_object_get_data ((GObject*) _tmp25_, "machine_state_id");
#line 232 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	machine_state_id = (gulong) ((guintptr) _tmp26_);
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp27_ = machine_state_id;
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp27_ != ((gulong) 0)) {
#line 2049 "collection-view.c"
		BoxesCollectionItem* _tmp28_ = NULL;
		gulong _tmp29_ = 0UL;
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp28_ = item;
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp29_ = machine_state_id;
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		g_signal_handler_disconnect ((GObject*) _tmp28_, _tmp29_);
#line 2058 "collection-view.c"
	}
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp30_ = item;
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if ((G_TYPE_CHECK_INSTANCE_TYPE (_tmp30_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp30_) : NULL) != NULL) {
#line 2064 "collection-view.c"
		BoxesMachine* machine = NULL;
		BoxesCollectionItem* _tmp31_ = NULL;
		BoxesMachine* _tmp32_ = NULL;
		gulong categories_id = 0UL;
		BoxesCollectionItem* _tmp33_ = NULL;
		gconstpointer _tmp34_ = NULL;
		BoxesMachine* _tmp35_ = NULL;
		BoxesBoxConfig* _tmp36_ = NULL;
		gulong _tmp37_ = 0UL;
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp31_ = item;
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp32_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp31_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp31_) : NULL);
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		machine = _tmp32_;
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp33_ = item;
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp34_ = g_object_get_data ((GObject*) _tmp33_, "categories_id");
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		categories_id = (gulong) ((guintptr) _tmp34_);
#line 239 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp35_ = machine;
#line 239 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp36_ = _tmp35_->config;
#line 239 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp37_ = categories_id;
#line 239 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		g_signal_handler_disconnect ((GObject*) _tmp36_, _tmp37_);
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (machine);
#line 2096 "collection-view.c"
	}
#line 212 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_free0 (iter);
#line 2100 "collection-view.c"
}


static BoxesCollectionItem* boxes_collection_view_get_item_for_iter (BoxesCollectionView* self, GtkTreeIter* iter) {
	BoxesCollectionItem* result = NULL;
	GValue value = {0};
	GtkListStore* _tmp0_ = NULL;
	GtkTreeIter _tmp1_ = {0};
	GValue _tmp2_ = {0};
	GValue _tmp3_ = {0};
	BoxesCollectionItem* _tmp4_ = NULL;
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (iter != NULL, NULL);
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->priv->store;
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = *iter;
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_tree_model_get_value ((GtkTreeModel*) _tmp0_, &_tmp1_, (gint) BOXES_COLLECTION_VIEW_MODEL_COLUMNS_ITEM, &_tmp2_);
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	G_IS_VALUE (&value) ? (g_value_unset (&value), NULL) : NULL;
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	value = _tmp2_;
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = value;
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp4_ = _g_object_ref0 (g_value_get_object (&_tmp3_));
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	result = _tmp4_;
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	G_IS_VALUE (&value) ? (g_value_unset (&value), NULL) : NULL;
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 2136 "collection-view.c"
}


static BoxesCollectionItem* boxes_collection_view_get_item_for_path (BoxesCollectionView* self, GtkTreePath* path) {
	BoxesCollectionItem* result = NULL;
	GtkTreeIter filter_iter = {0};
	GtkTreeIter iter = {0};
	GtkTreeModelFilter* _tmp0_ = NULL;
	GtkTreePath* _tmp1_ = NULL;
	GtkTreeIter _tmp2_ = {0};
	GtkTreeModelFilter* _tmp3_ = NULL;
	GtkTreeIter _tmp4_ = {0};
	GtkTreeIter _tmp5_ = {0};
	GtkTreeIter _tmp6_ = {0};
	BoxesCollectionItem* _tmp7_ = NULL;
#line 252 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 252 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (path != NULL, NULL);
#line 255 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->priv->model_filter;
#line 255 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = path;
#line 255 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_tree_model_get_iter ((GtkTreeModel*) _tmp0_, &_tmp2_, _tmp1_);
#line 255 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	filter_iter = _tmp2_;
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = self->priv->model_filter;
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp4_ = filter_iter;
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_tree_model_filter_convert_iter_to_child_iter (_tmp3_, &_tmp5_, &_tmp4_);
#line 256 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	iter = _tmp5_;
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp6_ = iter;
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp7_ = boxes_collection_view_get_item_for_iter (self, &_tmp6_);
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	result = _tmp7_;
#line 258 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 2180 "collection-view.c"
}


static gboolean boxes_collection_view_model_visible (BoxesCollectionView* self, GtkTreeModel* model, GtkTreeIter* iter) {
	gboolean result = FALSE;
	BoxesCollectionItem* item = NULL;
	GtkTreeIter _tmp0_ = {0};
	BoxesCollectionItem* _tmp1_ = NULL;
	BoxesCollectionItem* _tmp2_ = NULL;
	BoxesApp* _tmp3_ = NULL;
	BoxesCollectionFilter* _tmp4_ = NULL;
	BoxesCollectionItem* _tmp5_ = NULL;
	gboolean _tmp6_ = FALSE;
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (model != NULL, FALSE);
#line 261 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (iter != NULL, FALSE);
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = *iter;
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = boxes_collection_view_get_item_for_iter (self, &_tmp0_);
#line 262 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	item = _tmp1_;
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = item;
#line 263 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp2_ == NULL) {
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		result = FALSE;
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (item);
#line 264 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		return result;
#line 2216 "collection-view.c"
	}
#line 266 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = boxes_app_app;
#line 266 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp4_ = _tmp3_->filter;
#line 266 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp5_ = item;
#line 266 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp6_ = boxes_collection_filter_filter (_tmp4_, _tmp5_);
#line 266 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	result = _tmp6_;
#line 266 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (item);
#line 266 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 2232 "collection-view.c"
}


void boxes_collection_view_refilter (BoxesCollectionView* self) {
	GtkTreeModelFilter* _tmp0_ = NULL;
#line 269 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (self != NULL);
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->priv->model_filter;
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_tree_model_filter_refilter (_tmp0_);
#line 2244 "collection-view.c"
}


void boxes_collection_view_activate_first_item (BoxesCollectionView* self) {
	GtkTreeModelFilter* _tmp0_ = NULL;
	gint _tmp1_ = 0;
#line 273 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (self != NULL);
#line 274 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->priv->model_filter;
#line 274 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = gtk_tree_model_iter_n_children ((GtkTreeModel*) _tmp0_, NULL);
#line 274 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp1_ == 1) {
#line 2259 "collection-view.c"
		GtkTreePath* path = NULL;
		GtkTreePath* _tmp2_ = NULL;
		GtkWidget* _tmp3_ = NULL;
		GtkTreePath* _tmp4_ = NULL;
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp2_ = gtk_tree_path_new_from_string ("0");
#line 275 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		path = _tmp2_;
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp3_ = gd_main_view_get_generic_view ((GdMainView*) self);
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp4_ = path;
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		gtk_icon_view_item_activated (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, gtk_icon_view_get_type ()) ? ((GtkIconView*) _tmp3_) : NULL, _tmp4_);
#line 274 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_gtk_tree_path_free0 (path);
#line 2276 "collection-view.c"
	}
}


static gint __lambda26_ (BoxesCollectionView* self, GtkTreeModel* store, GtkTreeIter* a, GtkTreeIter* b) {
	gint result = 0;
	BoxesCollectionItem* item_a = NULL;
	BoxesCollectionItem* item_b = NULL;
	GtkTreeModel* _tmp0_ = NULL;
	GtkTreeIter _tmp1_ = {0};
	GtkTreeModel* _tmp2_ = NULL;
	GtkTreeIter _tmp3_ = {0};
	gboolean _tmp4_ = FALSE;
	BoxesCollectionItem* _tmp5_ = NULL;
	BoxesCollectionItem* _tmp7_ = NULL;
	BoxesCollectionItem* _tmp8_ = NULL;
	gint _tmp9_ = 0;
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (store != NULL, 0);
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (a != NULL, 0);
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (b != NULL, 0);
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = store;
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = *a;
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_tree_model_get (_tmp0_, &_tmp1_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_ITEM, &item_a, -1);
#line 295 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = store;
#line 295 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = *b;
#line 295 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_tree_model_get (_tmp2_, &_tmp3_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_ITEM, &item_b, -1);
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp5_ = item_a;
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp5_ == NULL) {
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp4_ = TRUE;
#line 2318 "collection-view.c"
	} else {
		BoxesCollectionItem* _tmp6_ = NULL;
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp6_ = item_b;
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp4_ = _tmp6_ == NULL;
#line 2325 "collection-view.c"
	}
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp4_) {
#line 298 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		result = 0;
#line 298 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (item_b);
#line 298 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (item_a);
#line 298 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		return result;
#line 2337 "collection-view.c"
	}
#line 300 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp7_ = item_a;
#line 300 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp8_ = item_b;
#line 300 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp9_ = boxes_collection_item_compare (_tmp7_, _tmp8_);
#line 300 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	result = _tmp9_;
#line 300 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (item_b);
#line 300 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (item_a);
#line 300 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 2353 "collection-view.c"
}


static gint ___lambda26__gtk_tree_iter_compare_func (GtkTreeModel* model, GtkTreeIter* a, GtkTreeIter* b, gpointer self) {
	gint result;
	result = __lambda26_ ((BoxesCollectionView*) self, model, a, b);
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 2362 "collection-view.c"
}


static void __lambda27_ (BoxesCollectionView* self) {
	BoxesApp* _tmp0_ = NULL;
#line 304 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = boxes_app_app;
#line 304 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_notify ((GObject*) _tmp0_, "selected-items");
#line 2372 "collection-view.c"
}


static void ___lambda27__gtk_tree_model_row_deleted (GtkTreeModel* _sender, GtkTreePath* path, gpointer self) {
#line 303 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	__lambda27_ ((BoxesCollectionView*) self);
#line 2379 "collection-view.c"
}


static void __lambda28_ (BoxesCollectionView* self) {
	BoxesApp* _tmp0_ = NULL;
#line 307 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = boxes_app_app;
#line 307 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_notify ((GObject*) _tmp0_, "selected-items");
#line 2389 "collection-view.c"
}


static void ___lambda28__gtk_tree_model_row_inserted (GtkTreeModel* _sender, GtkTreePath* path, GtkTreeIter* iter, gpointer self) {
#line 306 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	__lambda28_ ((BoxesCollectionView*) self);
#line 2396 "collection-view.c"
}


static gboolean _boxes_collection_view_model_visible_gtk_tree_model_filter_visible_func (GtkTreeModel* model, GtkTreeIter* iter, gpointer self) {
	gboolean result;
	result = boxes_collection_view_model_visible ((BoxesCollectionView*) self, model, iter);
#line 311 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 2405 "collection-view.c"
}


static void __lambda29_ (BoxesCollectionView* self, GdMainView* view, const gchar* id, GtkTreePath* path) {
	BoxesCollectionItem* item = NULL;
	GtkTreePath* _tmp0_ = NULL;
	BoxesCollectionItem* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	BoxesCollectionItem* _tmp3_ = NULL;
	BoxesAppWindow* _tmp7_ = NULL;
	BoxesCollectionItem* _tmp8_ = NULL;
#line 316 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (view != NULL);
#line 316 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (id != NULL);
#line 316 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (path != NULL);
#line 317 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = path;
#line 317 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = boxes_collection_view_get_item_for_path (self, _tmp0_);
#line 317 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	item = _tmp1_;
#line 318 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = item;
#line 318 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, BOXES_TYPE_LIBVIRT_MACHINE)) {
#line 2433 "collection-view.c"
		BoxesCollectionItem* _tmp4_ = NULL;
		gboolean _tmp5_ = FALSE;
		gboolean _tmp6_ = FALSE;
#line 318 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp4_ = item;
#line 318 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp5_ = boxes_libvirt_machine_get_importing (G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, BOXES_TYPE_LIBVIRT_MACHINE) ? ((BoxesLibvirtMachine*) _tmp4_) : NULL);
#line 318 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp6_ = _tmp5_;
#line 318 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp2_ = _tmp6_;
#line 2445 "collection-view.c"
	} else {
#line 318 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp2_ = FALSE;
#line 2449 "collection-view.c"
	}
#line 318 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp2_) {
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (item);
#line 319 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		return;
#line 2457 "collection-view.c"
	}
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp7_ = self->priv->window;
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp8_ = item;
#line 320 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	boxes_app_window_select_item (_tmp7_, _tmp8_);
#line 316 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (item);
#line 2467 "collection-view.c"
}


static void ___lambda29__gd_main_view_item_activated (GdMainView* _sender, const gchar* object, GtkTreePath* p0, gpointer self) {
#line 316 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	__lambda29_ ((BoxesCollectionView*) self, _sender, object, p0);
#line 2474 "collection-view.c"
}


static void __lambda44_ (BoxesCollectionView* self) {
	BoxesApp* _tmp0_ = NULL;
#line 323 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_widget_queue_draw ((GtkWidget*) self);
#line 324 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = boxes_app_app;
#line 324 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_notify ((GObject*) _tmp0_, "selected-items");
#line 2486 "collection-view.c"
}


static void ___lambda44__gd_main_view_view_selection_changed (GdMainView* _sender, gpointer self) {
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	__lambda44_ ((BoxesCollectionView*) self);
#line 2493 "collection-view.c"
}


static void boxes_collection_view_setup_view (BoxesCollectionView* self) {
	GtkListStore* _tmp0_ = NULL;
	GtkListStore* _tmp1_ = NULL;
	GtkListStore* _tmp2_ = NULL;
	GtkListStore* _tmp3_ = NULL;
	GtkListStore* _tmp4_ = NULL;
	GtkListStore* _tmp5_ = NULL;
	GtkTreeModelFilter* _tmp6_ = NULL;
	GtkTreeModelFilter* _tmp7_ = NULL;
	GtkTreeModelFilter* _tmp8_ = NULL;
	GtkStyleContext* _tmp9_ = NULL;
#line 280 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (self != NULL);
#line 281 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = gtk_list_store_new ((gint) BOXES_COLLECTION_VIEW_MODEL_COLUMNS_LAST, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, GDK_TYPE_PIXBUF, G_TYPE_LONG, G_TYPE_BOOLEAN, G_TYPE_UINT, BOXES_TYPE_COLLECTION_ITEM, -1);
#line 281 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (self->priv->store);
#line 281 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self->priv->store = _tmp0_;
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = self->priv->store;
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_tree_sortable_set_default_sort_func ((GtkTreeSortable*) _tmp1_, ___lambda26__gtk_tree_iter_compare_func, g_object_ref (self), g_object_unref);
#line 302 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = self->priv->store;
#line 302 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_tree_sortable_set_sort_column_id ((GtkTreeSortable*) _tmp2_, GTK_TREE_SORTABLE_DEFAULT_SORT_COLUMN_ID, GTK_SORT_ASCENDING);
#line 303 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = self->priv->store;
#line 303 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_signal_connect_object ((GtkTreeModel*) _tmp3_, "row-deleted", (GCallback) ___lambda27__gtk_tree_model_row_deleted, self, 0);
#line 306 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp4_ = self->priv->store;
#line 306 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_signal_connect_object ((GtkTreeModel*) _tmp4_, "row-inserted", (GCallback) ___lambda28__gtk_tree_model_row_inserted, self, 0);
#line 310 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp5_ = self->priv->store;
#line 310 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp6_ = (GtkTreeModelFilter*) gtk_tree_model_filter_new ((GtkTreeModel*) _tmp5_, NULL);
#line 310 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (self->priv->model_filter);
#line 310 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self->priv->model_filter = _tmp6_;
#line 311 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp7_ = self->priv->model_filter;
#line 311 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_tree_model_filter_set_visible_func (_tmp7_, _boxes_collection_view_model_visible_gtk_tree_model_filter_visible_func, g_object_ref (self), g_object_unref);
#line 313 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gd_main_view_set_view_type ((GdMainView*) self, GD_MAIN_VIEW_ICON);
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp8_ = self->priv->model_filter;
#line 314 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gd_main_view_set_model ((GdMainView*) self, (GtkTreeModel*) _tmp8_);
#line 315 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp9_ = gtk_widget_get_style_context ((GtkWidget*) self);
#line 315 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_style_context_add_class (_tmp9_, "content-bg");
#line 316 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_signal_connect_object ((GdMainView*) self, "item-activated", (GCallback) ___lambda29__gd_main_view_item_activated, self, 0);
#line 322 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_signal_connect_object ((GdMainView*) self, "view-selection-changed", (GCallback) ___lambda44__gd_main_view_view_selection_changed, self, 0);
#line 327 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_widget_show_all ((GtkWidget*) self);
#line 2560 "collection-view.c"
}


static Block22Data* block22_data_ref (Block22Data* _data22_) {
#line 330 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_atomic_int_inc (&_data22_->_ref_count_);
#line 330 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return _data22_;
#line 2569 "collection-view.c"
}


static void block22_data_unref (void * _userdata_) {
	Block22Data* _data22_;
	_data22_ = (Block22Data*) _userdata_;
#line 330 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (g_atomic_int_dec_and_test (&_data22_->_ref_count_)) {
#line 2578 "collection-view.c"
		BoxesCollectionView* self;
#line 330 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		self = _data22_->self;
#line 330 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (self);
#line 330 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		g_slice_free (Block22Data, _data22_);
#line 2586 "collection-view.c"
	}
}


static gboolean __lambda45_ (Block22Data* _data22_, GtkTreeModel* filter_model, GtkTreePath* filter_path, GtkTreeIter* filter_iter) {
	BoxesCollectionView* self;
	gboolean result = FALSE;
	GtkTreeIter iter = {0};
	GtkTreeModelFilter* _tmp0_ = NULL;
	GtkTreeIter _tmp1_ = {0};
	GtkTreeIter _tmp2_ = {0};
	gboolean selected = FALSE;
	BoxesSelectionCriteria _tmp3_ = 0;
	GtkListStore* _tmp12_ = NULL;
	GtkTreeIter _tmp13_ = {0};
	gboolean _tmp14_ = FALSE;
#line 333 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self = _data22_->self;
#line 333 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (filter_model != NULL, FALSE);
#line 333 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (filter_path != NULL, FALSE);
#line 333 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (filter_iter != NULL, FALSE);
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->priv->model_filter;
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = *filter_iter;
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_tree_model_filter_convert_iter_to_child_iter (_tmp0_, &_tmp2_, &_tmp1_);
#line 335 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	iter = _tmp2_;
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = _data22_->selection;
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	switch (_tmp3_) {
#line 2623 "collection-view.c"
		default:
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		case BOXES_SELECTION_CRITERIA_ALL:
#line 2627 "collection-view.c"
		{
#line 340 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			selected = TRUE;
#line 341 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			break;
#line 2633 "collection-view.c"
		}
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		case BOXES_SELECTION_CRITERIA_NONE:
#line 2637 "collection-view.c"
		{
#line 343 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			selected = FALSE;
#line 344 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			break;
#line 2643 "collection-view.c"
		}
#line 337 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		case BOXES_SELECTION_CRITERIA_RUNNING:
#line 2647 "collection-view.c"
		{
			BoxesCollectionItem* item = NULL;
			GtkListStore* _tmp4_ = NULL;
			GtkTreeIter _tmp5_ = {0};
			gboolean _tmp6_ = FALSE;
			gboolean _tmp7_ = FALSE;
			BoxesCollectionItem* _tmp8_ = NULL;
#line 347 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp4_ = self->priv->store;
#line 347 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp5_ = iter;
#line 347 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			gtk_tree_model_get ((GtkTreeModel*) _tmp4_, &_tmp5_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_ITEM, &item, -1);
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp8_ = item;
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			if (_tmp8_ != NULL) {
#line 2665 "collection-view.c"
				BoxesCollectionItem* _tmp9_ = NULL;
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
				_tmp9_ = item;
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
				_tmp7_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp9_, BOXES_TYPE_MACHINE);
#line 2671 "collection-view.c"
			} else {
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
				_tmp7_ = FALSE;
#line 2675 "collection-view.c"
			}
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			if (_tmp7_) {
#line 2679 "collection-view.c"
				BoxesCollectionItem* _tmp10_ = NULL;
				gboolean _tmp11_ = FALSE;
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
				_tmp10_ = item;
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
				_tmp11_ = boxes_machine_is_running (G_TYPE_CHECK_INSTANCE_TYPE (_tmp10_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp10_) : NULL);
#line 349 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
				_tmp6_ = _tmp11_;
#line 2688 "collection-view.c"
			} else {
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
				_tmp6_ = FALSE;
#line 2692 "collection-view.c"
			}
#line 348 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			selected = _tmp6_;
#line 350 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_g_object_unref0 (item);
#line 350 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			break;
#line 2700 "collection-view.c"
		}
	}
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp12_ = self->priv->store;
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp13_ = iter;
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp14_ = selected;
#line 352 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_list_store_set (_tmp12_, &_tmp13_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_SELECTED, _tmp14_, -1);
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	result = FALSE;
#line 353 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 2715 "collection-view.c"
}


static gboolean ___lambda45__gtk_tree_model_foreach_func (GtkTreeModel* model, GtkTreePath* path, GtkTreeIter* iter, gpointer self) {
	gboolean result;
	result = __lambda45_ (self, model, path, iter);
#line 333 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 2724 "collection-view.c"
}


void boxes_collection_view_select (BoxesCollectionView* self, BoxesSelectionCriteria selection) {
	Block22Data* _data22_;
	BoxesSelectionCriteria _tmp0_ = 0;
	BoxesAppWindow* _tmp1_ = NULL;
	GtkTreeModelFilter* _tmp2_ = NULL;
	BoxesApp* _tmp3_ = NULL;
#line 330 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (self != NULL);
#line 330 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data22_ = g_slice_new0 (Block22Data);
#line 330 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data22_->_ref_count_ = 1;
#line 330 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data22_->self = g_object_ref (self);
#line 330 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = selection;
#line 330 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data22_->selection = _tmp0_;
#line 331 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = self->priv->window;
#line 331 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	boxes_app_window_set_selection_mode (_tmp1_, TRUE);
#line 333 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = self->priv->model_filter;
#line 333 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_tree_model_foreach ((GtkTreeModel*) _tmp2_, ___lambda45__gtk_tree_model_foreach_func, _data22_);
#line 355 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_widget_queue_draw ((GtkWidget*) self);
#line 356 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = boxes_app_app;
#line 356 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_notify ((GObject*) _tmp3_, "selected-items");
#line 330 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	block22_data_unref (_data22_);
#line 330 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data22_ = NULL;
#line 2764 "collection-view.c"
}


static Block23Data* block23_data_ref (Block23Data* _data23_) {
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_atomic_int_inc (&_data23_->_ref_count_);
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return _data23_;
#line 2773 "collection-view.c"
}


static void block23_data_unref (void * _userdata_) {
	Block23Data* _data23_;
	_data23_ = (Block23Data*) _userdata_;
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (g_atomic_int_dec_and_test (&_data23_->_ref_count_)) {
#line 2782 "collection-view.c"
		BoxesCollectionView* self;
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		self = _data23_->self;
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (_data23_->machine);
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (self);
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		g_slice_free (Block23Data, _data23_);
#line 2792 "collection-view.c"
	}
}


static gboolean __lambda22_ (Block23Data* _data23_) {
	BoxesCollectionView* self;
	gboolean result = FALSE;
	GtkTreeIter* machine_iter = NULL;
	BoxesMachine* _tmp0_ = NULL;
	gconstpointer _tmp1_ = NULL;
	GtkTreeIter* _tmp2_ = NULL;
	GtkTreeIter* _tmp3_ = NULL;
	GtkListStore* _tmp4_ = NULL;
	GtkTreeIter* _tmp5_ = NULL;
	gint _tmp6_ = 0;
	GtkTreeIter _tmp7_ = {0};
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self = _data23_->self;
#line 384 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = _data23_->machine;
#line 384 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = g_object_get_data ((GObject*) _tmp0_, "iter");
#line 384 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = __gtk_tree_iter_dup0 ((GtkTreeIter*) _tmp1_);
#line 384 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	machine_iter = _tmp2_;
#line 385 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = machine_iter;
#line 385 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp3_ == NULL) {
#line 386 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		result = FALSE;
#line 386 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_free0 (machine_iter);
#line 386 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		return result;
#line 2829 "collection-view.c"
	}
#line 388 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp4_ = self->priv->store;
#line 388 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp5_ = machine_iter;
#line 388 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp6_ = _data23_->pulse;
#line 388 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data23_->pulse = _tmp6_ + 1;
#line 388 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp7_ = *_tmp5_;
#line 388 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_list_store_set (_tmp4_, &_tmp7_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_PULSE, _tmp6_, -1);
#line 389 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_widget_queue_draw ((GtkWidget*) self);
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	result = TRUE;
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_free0 (machine_iter);
#line 391 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 2851 "collection-view.c"
}


static gboolean ___lambda22__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda22_ (self);
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 2860 "collection-view.c"
}


static void boxes_collection_view_setup_activity (BoxesCollectionView* self, GtkTreeIter* iter, BoxesMachine* machine) {
	Block23Data* _data23_;
	BoxesMachine* _tmp0_ = NULL;
	BoxesMachine* _tmp1_ = NULL;
	guint activity_timeout = 0U;
	BoxesMachine* _tmp2_ = NULL;
	gconstpointer _tmp3_ = NULL;
	guint _tmp4_ = 0U;
	BoxesMachine* _tmp7_ = NULL;
	gboolean _tmp8_ = FALSE;
	gboolean _tmp9_ = FALSE;
	GtkListStore* _tmp18_ = NULL;
	GtkTreeIter _tmp19_ = {0};
	gint _tmp20_ = 0;
	BoxesMachine* _tmp21_ = NULL;
	BoxesMachineMachineState _tmp22_ = 0;
	BoxesMachineMachineState _tmp23_ = 0;
	guint _tmp24_ = 0U;
	BoxesMachine* _tmp25_ = NULL;
	guint _tmp26_ = 0U;
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (self != NULL);
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (iter != NULL);
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (machine != NULL);
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data23_ = g_slice_new0 (Block23Data);
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data23_->_ref_count_ = 1;
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data23_->self = g_object_ref (self);
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = machine;
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (_data23_->machine);
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data23_->machine = _tmp1_;
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = _data23_->machine;
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = g_object_get_data ((GObject*) _tmp2_, "activity_timeout");
#line 360 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	activity_timeout = (guint) ((guintptr) _tmp3_);
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp4_ = activity_timeout;
#line 361 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp4_ > ((guint) 0)) {
#line 2914 "collection-view.c"
		guint _tmp5_ = 0U;
		BoxesMachine* _tmp6_ = NULL;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp5_ = activity_timeout;
#line 362 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		g_source_remove (_tmp5_);
#line 363 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp6_ = _data23_->machine;
#line 363 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		g_object_set_data_full ((GObject*) _tmp6_, "activity_timeout", (gpointer) ((guintptr) ((guint) 0)), NULL);
#line 2925 "collection-view.c"
	}
#line 366 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp7_ = _data23_->machine;
#line 366 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp8_ = boxes_machine_get_under_construction (_tmp7_);
#line 366 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp9_ = _tmp8_;
#line 366 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (!_tmp9_) {
#line 2935 "collection-view.c"
		GtkListStore* _tmp10_ = NULL;
		GtkTreeIter _tmp11_ = {0};
		gulong machine_state_id = 0UL;
		BoxesMachine* _tmp12_ = NULL;
		gconstpointer _tmp13_ = NULL;
		gulong _tmp14_ = 0UL;
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp10_ = self->priv->store;
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp11_ = *iter;
#line 367 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		gtk_list_store_set (_tmp10_, &_tmp11_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_PULSE, 0, -1);
#line 368 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp12_ = _data23_->machine;
#line 368 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp13_ = g_object_get_data ((GObject*) _tmp12_, "machine_state_id");
#line 368 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		machine_state_id = (gulong) ((guintptr) _tmp13_);
#line 369 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp14_ = machine_state_id;
#line 369 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		if (_tmp14_ != ((gulong) 0)) {
#line 2958 "collection-view.c"
			BoxesMachine* _tmp15_ = NULL;
			gulong _tmp16_ = 0UL;
			BoxesMachine* _tmp17_ = NULL;
#line 370 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp15_ = _data23_->machine;
#line 370 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp16_ = machine_state_id;
#line 370 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			g_signal_handler_disconnect ((GObject*) _tmp15_, _tmp16_);
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			_tmp17_ = _data23_->machine;
#line 371 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
			g_object_set_data_full ((GObject*) _tmp17_, "machine_state_id", (gpointer) ((guintptr) ((gulong) 0)), NULL);
#line 2972 "collection-view.c"
		}
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		block23_data_unref (_data23_);
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_data23_ = NULL;
#line 374 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		return;
#line 2980 "collection-view.c"
	}
#line 377 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data23_->pulse = 1;
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp18_ = self->priv->store;
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp19_ = *iter;
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp20_ = _data23_->pulse;
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data23_->pulse = _tmp20_ + 1;
#line 378 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_list_store_set (_tmp18_, &_tmp19_, BOXES_COLLECTION_VIEW_MODEL_COLUMNS_PULSE, _tmp20_, -1);
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp21_ = _data23_->machine;
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp22_ = boxes_machine_get_state (_tmp21_);
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp23_ = _tmp22_;
#line 380 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp23_ == BOXES_MACHINE_MACHINE_STATE_SAVED) {
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		block23_data_unref (_data23_);
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_data23_ = NULL;
#line 381 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		return;
#line 3008 "collection-view.c"
	}
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp24_ = g_timeout_add_full (G_PRIORITY_DEFAULT, (guint) 150, ___lambda22__gsource_func, block23_data_ref (_data23_), block23_data_unref);
#line 383 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	activity_timeout = _tmp24_;
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp25_ = _data23_->machine;
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp26_ = activity_timeout;
#line 393 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_set_data_full ((GObject*) _tmp25_, "activity_timeout", (gpointer) ((guintptr) _tmp26_), NULL);
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	block23_data_unref (_data23_);
#line 359 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_data23_ = NULL;
#line 3024 "collection-view.c"
}


static gboolean boxes_collection_view_on_button_press_event (BoxesCollectionView* self, GdkEventButton* event) {
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	GdkEventButton* _tmp1_ = NULL;
	GdkEventType _tmp2_ = 0;
	GdMainViewGeneric* generic_view = NULL;
	GtkWidget* _tmp5_ = NULL;
	GdMainViewGeneric* _tmp6_ = NULL;
	GtkTreePath* path = NULL;
	GdMainViewGeneric* _tmp7_ = NULL;
	GdkEventButton* _tmp8_ = NULL;
	gdouble _tmp9_ = 0.0;
	GdkEventButton* _tmp10_ = NULL;
	gdouble _tmp11_ = 0.0;
	GtkTreePath* _tmp12_ = NULL;
	GtkTreePath* _tmp13_ = NULL;
	GtkTreePath* _tmp14_ = NULL;
	gboolean _tmp15_ = FALSE;
#line 396 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 396 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 397 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = event;
#line 397 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = _tmp1_->type;
#line 397 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp2_ != GDK_BUTTON_RELEASE) {
#line 397 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp0_ = TRUE;
#line 3058 "collection-view.c"
	} else {
		GdkEventButton* _tmp3_ = NULL;
		guint _tmp4_ = 0U;
#line 397 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp3_ = event;
#line 397 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp4_ = _tmp3_->button;
#line 397 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_tmp0_ = _tmp4_ != ((guint) 3);
#line 3068 "collection-view.c"
	}
#line 397 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp0_) {
#line 398 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		result = FALSE;
#line 398 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		return result;
#line 3076 "collection-view.c"
	}
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp5_ = gd_main_view_get_generic_view ((GdMainView*) self);
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp6_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, gd_main_view_generic_get_type ()) ? ((GdMainViewGeneric*) _tmp5_) : NULL);
#line 400 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	generic_view = _tmp6_;
#line 401 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp7_ = generic_view;
#line 401 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp8_ = event;
#line 401 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp9_ = _tmp8_->x;
#line 401 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp10_ = event;
#line 401 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp11_ = _tmp10_->y;
#line 401 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp12_ = gd_main_view_generic_get_path_at_pos (_tmp7_, (gint) _tmp9_, (gint) _tmp11_);
#line 401 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	path = _tmp12_;
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp13_ = path;
#line 402 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp13_ == NULL) {
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		result = FALSE;
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_gtk_tree_path_free0 (path);
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (generic_view);
#line 403 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		return result;
#line 3110 "collection-view.c"
	}
#line 405 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp14_ = path;
#line 405 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp15_ = boxes_collection_view_launch_context_popover_for_path (self, _tmp14_);
#line 405 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	result = _tmp15_;
#line 405 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_gtk_tree_path_free0 (path);
#line 405 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (generic_view);
#line 405 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 3124 "collection-view.c"
}


static gboolean boxes_collection_view_on_key_press_event (BoxesCollectionView* self, GdkEventKey* event) {
	gboolean result = FALSE;
	GdkEventKey* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	GtkIconView* icon_view = NULL;
	GtkWidget* _tmp2_ = NULL;
	GtkIconView* _tmp3_ = NULL;
	GtkTreePath* path = NULL;
	GtkCellRenderer* cell = NULL;
	GtkIconView* _tmp4_ = NULL;
	GtkTreePath* _tmp5_ = NULL;
	GtkCellRenderer* _tmp6_ = NULL;
	gboolean _tmp7_ = FALSE;
	GtkCellRenderer* _tmp8_ = NULL;
	GtkTreePath* _tmp9_ = NULL;
	gboolean _tmp10_ = FALSE;
#line 408 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 408 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 409 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = event;
#line 409 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = _tmp0_->keyval;
#line 409 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp1_ != ((guint) GDK_KEY_Menu)) {
#line 410 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		result = FALSE;
#line 410 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		return result;
#line 3158 "collection-view.c"
	}
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = gd_main_view_get_generic_view ((GdMainView*) self);
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, gtk_icon_view_get_type ()) ? ((GtkIconView*) _tmp2_) : NULL);
#line 412 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	icon_view = _tmp3_;
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp4_ = icon_view;
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp7_ = gtk_icon_view_get_cursor (_tmp4_, &_tmp5_, &_tmp6_);
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_gtk_tree_path_free0 (path);
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	path = _tmp5_;
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (cell);
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp8_ = _g_object_ref0 (_tmp6_);
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	cell = _tmp8_;
#line 415 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (!_tmp7_) {
#line 416 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		result = FALSE;
#line 416 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (cell);
#line 416 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_gtk_tree_path_free0 (path);
#line 416 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (icon_view);
#line 416 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		return result;
#line 3192 "collection-view.c"
	}
#line 418 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp9_ = path;
#line 418 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp10_ = boxes_collection_view_launch_context_popover_for_path (self, _tmp9_);
#line 418 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	result = _tmp10_;
#line 418 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (cell);
#line 418 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_gtk_tree_path_free0 (path);
#line 418 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (icon_view);
#line 418 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 3208 "collection-view.c"
}


static gboolean boxes_collection_view_launch_context_popover_for_path (BoxesCollectionView* self, GtkTreePath* path) {
	gboolean result = FALSE;
	BoxesCollectionItem* item = NULL;
	GtkTreePath* _tmp0_ = NULL;
	BoxesCollectionItem* _tmp1_ = NULL;
	BoxesCollectionItem* _tmp2_ = NULL;
	GtkIconView* icon_view = NULL;
	GtkWidget* _tmp3_ = NULL;
	GtkIconView* _tmp4_ = NULL;
	GdkRectangle rect = {0};
	GtkIconView* _tmp5_ = NULL;
	GtkTreePath* _tmp6_ = NULL;
	GdkRectangle _tmp7_ = {0};
	BoxesActionsPopover* _tmp8_ = NULL;
	BoxesCollectionItem* _tmp9_ = NULL;
	gint _tmp10_ = 0;
	BoxesActionsPopover* _tmp11_ = NULL;
	GdkRectangle _tmp12_ = {0};
	BoxesActionsPopover* _tmp13_ = NULL;
#line 421 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 421 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (path != NULL, FALSE);
#line 422 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = path;
#line 422 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = boxes_collection_view_get_item_for_path (self, _tmp0_);
#line 422 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	item = _tmp1_;
#line 423 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = item;
#line 423 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	if (_tmp2_ == NULL) {
#line 424 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		result = FALSE;
#line 424 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		_g_object_unref0 (item);
#line 424 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		return result;
#line 3251 "collection-view.c"
	}
#line 426 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp3_ = gd_main_view_get_generic_view ((GdMainView*) self);
#line 426 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp4_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, gtk_icon_view_get_type ()) ? ((GtkIconView*) _tmp3_) : NULL);
#line 426 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	icon_view = _tmp4_;
#line 428 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp5_ = icon_view;
#line 428 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp6_ = path;
#line 428 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_icon_view_get_cell_rect (_tmp5_, _tmp6_, NULL, &_tmp7_);
#line 428 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	rect = _tmp7_;
#line 430 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp8_ = self->priv->context_popover;
#line 430 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp9_ = item;
#line 430 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	boxes_actions_popover_update_for_item (_tmp8_, _tmp9_);
#line 431 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp10_ = rect.height;
#line 431 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	rect.height = _tmp10_ / 2;
#line 432 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp11_ = self->priv->context_popover;
#line 432 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp12_ = rect;
#line 432 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_popover_set_pointing_to ((GtkPopover*) _tmp11_, &_tmp12_);
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp13_ = self->priv->context_popover;
#line 433 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	gtk_widget_show ((GtkWidget*) _tmp13_);
#line 435 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	result = TRUE;
#line 435 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (icon_view);
#line 435 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (item);
#line 435 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 3295 "collection-view.c"
}


BoxesCollectionView* boxes_collection_view_construct (GType object_type) {
	BoxesCollectionView * self = NULL;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self = (BoxesCollectionView*) g_object_new (object_type, NULL);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return self;
#line 3305 "collection-view.c"
}


BoxesCollectionView* boxes_collection_view_new (void) {
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return boxes_collection_view_construct (BOXES_TYPE_COLLECTION_VIEW);
#line 3312 "collection-view.c"
}


static BoxesUIState boxes_collection_view_real_get_previous_ui_state (BoxesUI* base) {
	BoxesUIState result;
	BoxesCollectionView* self;
	BoxesUIState _tmp0_ = 0;
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self = (BoxesCollectionView*) base;
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->priv->_previous_ui_state;
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	result = _tmp0_;
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 3328 "collection-view.c"
}


static void boxes_collection_view_real_set_previous_ui_state (BoxesUI* base, BoxesUIState value) {
	BoxesCollectionView* self;
	BoxesUIState _tmp0_ = 0;
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self = (BoxesCollectionView*) base;
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = value;
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self->priv->_previous_ui_state = _tmp0_;
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_notify ((GObject *) self, "previous-ui-state");
#line 3343 "collection-view.c"
}


static BoxesUIState boxes_collection_view_real_get_ui_state (BoxesUI* base) {
	BoxesUIState result;
	BoxesCollectionView* self;
	BoxesUIState _tmp0_ = 0;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self = (BoxesCollectionView*) base;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->priv->_ui_state;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	result = _tmp0_;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 3359 "collection-view.c"
}


static void boxes_collection_view_real_set_ui_state (BoxesUI* base, BoxesUIState value) {
	BoxesCollectionView* self;
	BoxesUIState _tmp0_ = 0;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self = (BoxesCollectionView*) base;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = value;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self->priv->_ui_state = _tmp0_;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_notify ((GObject *) self, "ui-state");
#line 3374 "collection-view.c"
}


BoxesCategory* boxes_collection_view_get_category (BoxesCollectionView* self) {
	BoxesCategory* result;
	BoxesCategory* _tmp0_ = NULL;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = self->priv->_category;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	result = _tmp0_;
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return result;
#line 3389 "collection-view.c"
}


void boxes_collection_view_set_category (BoxesCollectionView* self, BoxesCategory* value) {
	BoxesCategory* _tmp0_ = NULL;
	BoxesCategory* _tmp1_ = NULL;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_return_if_fail (self != NULL);
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = value;
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (self->priv->_category);
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self->priv->_category = _tmp1_;
#line 18 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_notify ((GObject *) self, "category");
#line 3408 "collection-view.c"
}


static void _boxes_collection_view_ui_state_changed_g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	boxes_collection_view_ui_state_changed ((BoxesCollectionView*) self);
#line 3415 "collection-view.c"
}


static GObject * boxes_collection_view_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	BoxesCollectionView * self;
	const gchar* _tmp0_ = NULL;
	BoxesCategory* _tmp1_ = NULL;
	BoxesCategory* _tmp2_ = NULL;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	parent_class = G_OBJECT_CLASS (boxes_collection_view_parent_class);
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp0_ = _ ("New and Recent");
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp1_ = boxes_category_new (_tmp0_, BOXES_CATEGORY_KIND_NEW);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_tmp2_ = _tmp1_;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	boxes_collection_view_set_category (self, _tmp2_);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (_tmp2_);
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	__g_list_free__g_object_unref0_0 (self->priv->hidden_items);
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self->priv->hidden_items = NULL;
#line 43 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	boxes_collection_view_setup_view (self);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_signal_connect_object ((GObject*) self, "notify::ui-state", (GCallback) _boxes_collection_view_ui_state_changed_g_object_notify, self, 0);
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	return obj;
#line 3452 "collection-view.c"
}


static void boxes_collection_view_class_init (BoxesCollectionViewClass * klass) {
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	boxes_collection_view_parent_class = g_type_class_peek_parent (klass);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_type_class_add_private (klass, sizeof (BoxesCollectionViewPrivate));
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_collection_view_get_property;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_collection_view_set_property;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	G_OBJECT_CLASS (klass)->constructor = boxes_collection_view_constructor;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_collection_view_finalize;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_COLLECTION_VIEW_PREVIOUS_UI_STATE, g_param_spec_enum ("previous-ui-state", "previous-ui-state", "previous-ui-state", BOXES_TYPE_UI_STATE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_COLLECTION_VIEW_UI_STATE, g_param_spec_enum ("ui-state", "ui-state", "ui-state", BOXES_TYPE_UI_STATE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_COLLECTION_VIEW_CATEGORY, g_param_spec_object ("category", "category", "category", BOXES_TYPE_CATEGORY, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 3475 "collection-view.c"
}


static void boxes_collection_view_boxes_ui_interface_init (BoxesUIIface * iface) {
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	boxes_collection_view_boxes_ui_parent_iface = g_type_interface_peek_parent (iface);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	iface->get_previous_ui_state = boxes_collection_view_real_get_previous_ui_state;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	iface->set_previous_ui_state = boxes_collection_view_real_set_previous_ui_state;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	iface->get_ui_state = boxes_collection_view_real_get_ui_state;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	iface->set_ui_state = boxes_collection_view_real_set_ui_state;
#line 3490 "collection-view.c"
}


static void boxes_collection_view_instance_init (BoxesCollectionView * self) {
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self->priv = BOXES_COLLECTION_VIEW_GET_PRIVATE (self);
#line 3497 "collection-view.c"
}


static void boxes_collection_view_finalize (GObject* obj) {
	BoxesCollectionView * self;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (self->priv->window);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (self->priv->_category);
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (self->priv->store);
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (self->priv->model_filter);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	_g_object_unref0 (self->priv->context_popover);
#line 38 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	__g_list_free__g_object_unref0_0 (self->priv->hidden_items);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	G_OBJECT_CLASS (boxes_collection_view_parent_class)->finalize (obj);
#line 3519 "collection-view.c"
}


GType boxes_collection_view_get_type (void) {
	static volatile gsize boxes_collection_view_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_collection_view_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesCollectionViewClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_collection_view_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesCollectionView), 0, (GInstanceInitFunc) boxes_collection_view_instance_init, NULL };
		static const GInterfaceInfo boxes_ui_info = { (GInterfaceInitFunc) boxes_collection_view_boxes_ui_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType boxes_collection_view_type_id;
		boxes_collection_view_type_id = g_type_register_static (gd_main_view_get_type (), "BoxesCollectionView", &g_define_type_info, 0);
		g_type_add_interface_static (boxes_collection_view_type_id, BOXES_TYPE_UI, &boxes_ui_info);
		g_once_init_leave (&boxes_collection_view_type_id__volatile, boxes_collection_view_type_id);
	}
	return boxes_collection_view_type_id__volatile;
}


static void _vala_boxes_collection_view_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesCollectionView * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	switch (property_id) {
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		case BOXES_COLLECTION_VIEW_PREVIOUS_UI_STATE:
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		g_value_set_enum (value, boxes_ui_get_previous_ui_state ((BoxesUI*) self));
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		break;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		case BOXES_COLLECTION_VIEW_UI_STATE:
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		g_value_set_enum (value, boxes_ui_get_ui_state ((BoxesUI*) self));
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		break;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		case BOXES_COLLECTION_VIEW_CATEGORY:
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		g_value_set_object (value, boxes_collection_view_get_category (self));
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		break;
#line 3560 "collection-view.c"
		default:
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		break;
#line 3566 "collection-view.c"
	}
}


static void _vala_boxes_collection_view_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesCollectionView * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
	switch (property_id) {
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		case BOXES_COLLECTION_VIEW_PREVIOUS_UI_STATE:
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		boxes_ui_set_previous_ui_state ((BoxesUI*) self, g_value_get_enum (value));
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		break;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		case BOXES_COLLECTION_VIEW_UI_STATE:
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		boxes_ui_set_ui_state ((BoxesUI*) self, g_value_get_enum (value));
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		break;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		case BOXES_COLLECTION_VIEW_CATEGORY:
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		boxes_collection_view_set_category (self, g_value_get_object (value));
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		break;
#line 3594 "collection-view.c"
		default:
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/collection-view.vala"
		break;
#line 3600 "collection-view.c"
	}
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}



